% This program is written by Naoki Wakamori and Angelika Welte
% If needed, please customize directory in the following line: 
% cd C:\Users\wela\Dropbox\WakamoriWelte2012\01_ProgramsAndData\03_Matlab\11_Estimation\version45
rng(2016)


%% Part(1): Some preparations for this entire program %% 

    % Please customize this line
        clear;
        clc;
    
    % Defining the Global variables %
        global T allCS allDE num sigma mu W W12 allXc allXd  ...
               allXcr allXdr allIC subs

    % Deciding variables included
        cd ../../EstimableData
        CreMean = csvread('data_CreMean.csv');
        CreRand = csvread('data_CreRand.csv');
        DebMean = csvread('data_DebMean.csv');
        DebRand = csvread('data_DebRand.csv');
        
        num.CreMean = size(CreMean,2);
        num.CreRand = size(CreRand,2);
        num.DebMean = size(DebMean,2);
        num.DebRand = size(DebRand,2);
        
    % Deciding the model
        num.models =    6; % No. of Models estimated
        num.sim    =  100; % No. of Simulations
        num.sigmas =    2; % No. of Scale Coefficients (\sigma)
        num.base   =  num.CreMean + num.DebMean + 2 ; % No. of base parameters (\bar{\beta})
        num.mus    =  num.CreRand + num.DebRand     ; % No. of Random Coefficients (\mu)
        
        num.random = num.mus + num.sigmas;  % No. of RVs needed to generate
        
        num.param1 = num.base;             
        num.param2 = num.base;             
        num.param3 = num.base;                  
        num.param4 = num.base + num.sigmas;
        num.param5 = num.base + num.mus;
        num.param6 = num.base + num.mus + num.sigmas; 
        
        
        
        
    % Setting a initial_guess vector
        ini.g1 = zeros(1,num.param1);
        ini.g2 = zeros(1,num.param2);
        ini.g3 = zeros(1,num.param3);
        ini.g4 = zeros(1,num.param4);
        ini.g5 = zeros(1,num.param5);
        ini.g6 = zeros(1,num.param6);

    % Setting a trancation parameter 
        trnctn = 2.0;

    % Creating the stock
        InfoCri   = zeros(3,num.models);
    
        
%% Part(2): Loading data and Customizing the format of data %%

    % Loading the data 
        data = csvread('data_v44ind.csv');
        cd ../Estimation/version45

    % Determining some variables, based on the data
    
        % Number of individuals
            num.ind      = size( unique(data(:,1)), 1 );
            num.alltrans = size( data, 1);
        
        % Number of shopping opportunities and Weights for each individual
            T   = zeros(num.ind,1);
            W   = zeros(num.ind,1); % Weight in convenient formal [num.ind, 1]
            W12 = data(:,4);        % Weight in Original format [num.alltrans, 1]
            t = 1;
            subs = zeros(num.alltrans, 1);
             for n=1:num.ind
                
                T(n) = data(t,3); 
                subs(t: t+ T(n) - 1) = n;
                W(n) = data(t,4);
                t    = t + T(n);
               
            end
           
        % Decisions that each individual made
           allDE = data(:, 5: 7);
            
        % "Percieved" Choice Set Information 
            allCS = data(:, 8:10);
            
            
            allIC = allDE;
            
        % Imputed Choice Set Information
            allIC(:,1) = max(0, allCS(:,1) - data(:,14) ); % Cash "never" users
            allIC(:,2) = max(0, allCS(:,2) - data(:,15) ); % Credit "never" users
            allIC(:,3) = max(0, allCS(:,3) - data(:,16) ); % Credit "never" users  
            
            
            
            
            allICold  =allIC;
            allIC(:,1) = max(allIC(:,1) , allDE(:,1) );
            allIC(:,2) = max(allIC(:,2) , allDE(:,2) );
            allIC(:,3) = max(allIC(:,3) , allDE(:,3) );
            
            
        % Transaction Characteristics
            allXc  = [ ones(num.alltrans,1) CreMean CreRand ];
            allXd  = [ ones(num.alltrans,1) DebMean DebRand ];
            
            dummyvar = sum(reshape(allXc==1|allXc==0,size(allXc))) == size(allXc,1);
            sfc = 1 ./ mean(abs(allXc));
            sfc = dummyvar + (1-dummyvar) .* sfc;
            allXc = allXc .* repmat(sfc,num.alltrans,1);
    
            dummyvar = sum(reshape(allXd==1|allXd==0,size(allXd))) == size(allXd,1);
            sfd = 1 ./ mean(abs(allXd));
            sfd = dummyvar + (1-dummyvar) .* sfd;
            allXd = allXd .* repmat(sfd,num.alltrans,1);
           
        
            allXcr = allXc(:, num.CreMean+ 2:end);
            allXdr = allXd(:,num.DebMean + 2:end);
            
            allXc = allXc(:,1:num.CreMean + 1 );
            allXd = allXd(:, 1:num.DebMean + 1);
            
            
%% Part(3): Generating random variables for simulations %% 
        
    % Generating random variables (scale params. and random coefficients)
        m_seed = randn(num.ind,      num.mus,    num.sim );
        s_seed = randn(num.ind,      num.sigmas, num.sim );
        mu     = zeros(num.alltrans, num.mus,    num.sim );
        sigma  = zeros(num.alltrans, num.sigmas, num.sim );
        tt     = [0,0];

     % Truncated sigma and mu by plus/minus 2    
        s_seed = min(abs(s_seed), 2).*sign(s_seed);
       m_seed = min(abs(m_seed), 2).*sign(m_seed);
     
     
       
       
          t_ind = cumsum(accumarray(cumsum(T),1));
          t_ind(2:end) = t_ind(1:end-1);
          t_ind = t_ind+ 1;
             mu= m_seed(t_ind, :, :);
             sigma= s_seed(t_ind, :, :);
        clear m_seed s_seed
      

        
        
%% Part(3): Minimizing the objective function and calculating Std. Err. %%

    % Minimizing the objective function 
        OPTIONS = optimset('MaxFunEvals',10000000, 'MaxIter',50000000);
        
        % Model 1 
            [min_vec1, ~         ] = fminunc(@obj01, ini.g1, OPTIONS);
            [min_vec1, min_fval1 ] = fminsearch(@obj01, min_vec1, OPTIONS);
            save min_vec1 min_vec1
            save min_fval1 min_fval1

            df1     = 1.0E-006*min_vec1;
            score1  = zeros(num.alltrans,num.param1);
            InfMat1 = zeros(num.param1);            

            for p=1:num.param1 
                opt_plus1     = min_vec1;
                opt_minu1     = min_vec1;
                opt_plus1(p)  = min_vec1(p) + df1(p);
                opt_minu1(p)  = min_vec1(p) - df1(p);
                [ ~, dev_p1 ] = obj01(opt_plus1);
                [ ~, dev_m1 ] = obj01(opt_minu1);
                score1(:,p)   = abs(dev_p1 - dev_m1 )/(2*df1(p));
            end             

            for n=1:num.alltrans
                InfMat1 = InfMat1 + (W12(n)/num.alltrans)*score1(n,:)'*score1(n,:);
            end
            
            Avar1        = InfMat1\eye(num.param1);            
            StdErr1      = sqrt(diag(Avar1/num.alltrans));
            InfoCri(1,1) = -min_fval1;            
            InfoCri(2,1) = 2*num.param1 + 2*min_fval1;
            InfoCri(3,1) = 2*min_fval1  + num.param1*log(num.alltrans);            
            
            results1 = [ min_vec1' StdErr1 ];
            save results1 results1
            
            
        % Model 2 
            [min_vec2, ~         ] = fminunc(@obj02, ini.g2, OPTIONS);
            [min_vec2, min_fval2 ] = fminsearch(@obj02, min_vec2, OPTIONS);
            save min_vec2 min_vec2
            save min_fval2 min_fval2

            df2     = 1.0E-006*min_vec2;
            score2  = zeros(num.alltrans,num.param2);
            InfMat2 = zeros(num.param2);            

            for p=1:num.param1
                opt_plus2     = min_vec2;
                opt_minu2     = min_vec2;
                opt_plus2(p)  = min_vec2(p) + df2(p);
                opt_minu2(p)  = min_vec2(p) - df2(p);
                [ ~, dev_p2 ] = obj02(opt_plus2);
                [ ~, dev_m2 ] = obj02(opt_minu2);
                score2(:,p)   = abs(dev_p2 - dev_m2 )/(2*df2(p));
            end             

            for n=1:num.alltrans
                InfMat2 = InfMat2 + (W12(n)/num.alltrans)*score2(n,:)'*score2(n,:);
            end
            
            Avar2        = InfMat2\eye(num.param2);            
            StdErr2      = sqrt(diag(Avar2/num.alltrans));
            InfoCri(1,2) = -min_fval2;            
            InfoCri(2,2) = 2*num.param2 + 2*min_fval2;
            InfoCri(3,2) = 2*min_fval2  + num.param2*log(num.alltrans);            
            
            results2 = [ min_vec2' StdErr2 ];
            save results2 results2
        
        
        % Model 3
            [min_vec3, ~         ] = fminunc(@obj03, ini.g3, OPTIONS);
            [min_vec3, min_fval3 ] = fminsearch(@obj03, min_vec3, OPTIONS);
            save min_vec3 min_vec3
            save min_fval3 min_fval3

            df3     = 1.0E-006*min_vec3;
            score3  = zeros(num.ind,num.param3);
            InfMat3 = zeros(num.param3);            

            for p=1:num.param3
                opt_plus3     = min_vec3;
                opt_minu3     = min_vec3;
                opt_plus3(p)  = min_vec3(p) + df3(p);
                opt_minu3(p)  = min_vec3(p) - df3(p);
                [ ~, dev_p3 ] = obj03(opt_plus3);
                [ ~, dev_m3 ] = obj03(opt_minu3);
                score3(:,p)   = abs(dev_p3 - dev_m3 )/(2*df3(p));
            end             

            for n=1:num.ind
                InfMat3 = InfMat3 + (W(n)/num.ind)*score3(n,:)'*score3(n,:);
            end
            
            Avar3        = InfMat3\eye(num.param3);            
            StdErr3      = sqrt(diag(Avar3/num.ind));
            InfoCri(1,3) = -min_fval3;
            InfoCri(2,3) = 2*num.param3 + 2*min_fval3;
            InfoCri(3,3) = 2*min_fval3  + num.param3*log(num.ind);            
            
            results3 = [ min_vec3' StdErr3 ];
            save results3 results3

            
        % Model 4
            ini.g4(1:num.base)     = min_vec3(1:num.base);
            [min_vec4, ~         ] = fminunc(@obj04, ini.g4);
            [min_vec4, min_fval4 ] = fminsearch(@obj04, min_vec4, OPTIONS);
            save min_vec4 min_vec4
            save min_fval4 min_fval4

            df4     = 1.0E-006*min_vec4;
            score4  = zeros(num.ind,num.param4);
            InfMat4 = zeros(num.param4);

            for p=1:num.param4
                opt_plus4     = min_vec4;
                opt_minu4     = min_vec4;
                opt_plus4(p)  = min_vec4(p) + df4(p);
                opt_minu4(p)  = min_vec4(p) - df4(p);
                [ ~, dev_p4 ] = obj04(opt_plus4);
                [ ~, dev_m4 ] = obj04(opt_minu4);
                score4(:,p)   = abs(dev_p4 - dev_m4 )/(2*df4(p));
            end             

            for n=1:num.ind
                InfMat4 = InfMat4 + (W(n)/num.ind)*score4(n,:)'*score4(n,:);
            end
            
            Avar4   = InfMat4\eye(num.param4);
            StdErr4 = sqrt(diag(Avar4/num.ind));
            InfoCri(1,4) = -min_fval4;
            InfoCri(2,4) = 2*num.param4 + 2*min_fval4;
            InfoCri(3,4) = 2*min_fval4  + num.param4*log(num.ind);
            
            results4 = [ min_vec4' StdErr4 ];
            save results4 results4

            
        % Model 5
            ini.g5(1:num.base)     = min_vec3(1:num.base);
            [min_vec5, ~         ] = fminunc(@obj05, ini.g5, OPTIONS);
            [min_vec5, min_fval5 ] = fminsearch(@obj05, min_vec5, OPTIONS);
            save min_vec5 min_vec5
            save min_fval5 min_fval5

            df5     = 1.0E-006*min_vec5;
            score5  = zeros(num.ind,num.param5);
            InfMat5 = zeros(num.param5);

            for p=1:num.param5
                opt_plus5     = min_vec5;
                opt_minu5     = min_vec5;
                opt_plus5(p)  = min_vec5(p) + df5(p);
                opt_minu5(p)  = min_vec5(p) - df5(p);
                [ ~, dev_p5 ] = obj05(opt_plus5);
                [ ~, dev_m5 ] = obj05(opt_minu5);
                score5(:,p)   = abs(dev_p5 - dev_m5 )/(2*df5(p));
            end             
            
            for n=1:num.ind
                InfMat5 = InfMat5 + (W(n)/num.ind)*score5(n,:)'*score5(n,:);
            end

            Avar5   = InfMat5\eye(num.param5);
            StdErr5 = sqrt(diag(Avar5/num.ind));
            InfoCri(1,5) = -min_fval5;
            InfoCri(2,5) = 2*num.param5 + 2*min_fval5;
            InfoCri(3,5) = 2*min_fval5  + num.param5*log(num.ind);            
            
            results5 = [ min_vec5' StdErr5 ];
            save results5 results5

            
        % Model 6
            ini.g6(1:num.param5 )    = min_vec5;
            ini.g6(end-1:end)     = min_vec4(end-1: end);
            load min_vec3
            ini.g6(1:num.param3 )    = min_vec3;
            [min_vec6, ~         ] = fminunc(@obj06, ini.g6, OPTIONS);
            [min_vec6, min_fval6 ] = fminsearch(@obj06, min_vec6, OPTIONS);
            save min_vec6 min_vec6
            save min_fval6 min_fval6
            
            df6     = 1.0E-006*min_vec6;
            score6  = zeros(num.ind,num.param6);
            InfMat6 = zeros(num.param6);

            for p=1:num.param6
                opt_plus6     = min_vec6;
                opt_minu6     = min_vec6;
                opt_plus6(p)  = min_vec6(p) + df6(p);
                opt_minu6(p)  = min_vec6(p) - df6(p);
                [ ~, dev_p6 ] = obj06(opt_plus6);
                [ ~, dev_m6 ] = obj06(opt_minu6);
                score6(:,p)   = abs(dev_p6 - dev_m6 )/(2*df6(p));
            end 

            for n=1:num.ind
                InfMat6 = InfMat6 + (W(n)/num.ind)*score6(n,:)'*score6(n,:);
            end

            Avar6   = InfMat6\eye(num.param6);
            StdErr6 = sqrt(diag(Avar6/num.ind));
            InfoCri(1,6) = -min_fval6;            
            InfoCri(2,6) = 2*num.param6 + 2*min_fval6;
            InfoCri(3,6) = 2*min_fval6  + num.param6*log(num.ind);            

            results6 = [ min_vec6' StdErr6 ];
            save results6 results6


  save InfoCri InfoCri          
            
%% Fitness of the Models %%

    % Preparation
        WGHT = data(:,4);
        WTV  = data(:,11).*WGHT; 

        
    % Data 
        Freq.MacroCash(1)    = sum( allDE(:,1).*WGHT )/sum( WGHT ); 
        Freq.MacroCredit(1)  = sum( allDE(:,2).*WGHT )/sum( WGHT ); 
        Freq.MacroDebit(1)   = sum( allDE(:,3).*WGHT )/sum( WGHT ); 
        Value.MacroCash(1)   = sum( allDE(:,1).*WTV  )/sum( WTV ); 
        Value.MacroCredit(1) = sum( allDE(:,2).*WTV  )/sum( WTV ); 
        Value.MacroDebit(1)  = sum( allDE(:,3).*WTV  )/sum( WTV );

        
    % Model 3
        load results3

        beta_c = results3( 1:num.CreMean + 1, 1);
        beta_d = results3(num.CreMean + 2:num.base, 1);
    
        allUT      = ones(num.alltrans,3);
        allUT(:,1) = 1;
        allUT(:,2) = exp( allXc*beta_c );
        allUT(:,3) = exp( allXd*beta_d );
        allCP      = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));

        Freq.MacroCash(2)    = sum( allCP(:,1).*WGHT )/sum( WGHT );
        Freq.MacroCredit(2)  = sum( allCP(:,2).*WGHT )/sum( WGHT );
        Freq.MacroDebit(2)   = sum( allCP(:,3).*WGHT )/sum( WGHT );
        Value.MacroCash(2)   = sum( allCP(:,1).*WTV  )/sum( WTV  );
        Value.MacroCredit(2) = sum( allCP(:,2).*WTV  )/sum( WTV  );
        Value.MacroDebit(2)  = sum( allCP(:,3).*WTV  )/sum( WTV  );

        
    % Model 4
        load results4
        allCP         = zeros(num.alltrans,3,num.sim);
        
        beta_c  = results4( 1:num.CreMean + 1, 1);
        beta_d  = results4(num.CreMean + 2:num.base, 1);
        tau_c   = results4(num.base + 1, 1);
        tau_d   = results4(num.base + 2, 1);  
        
        for s = 1:num.sim
            sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
            sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
                
            allUT      = ones(num.alltrans,3);
            allUT(:,1) = 1; 
            allUT(:,2) = exp( sigma_c.*(allXc*beta_c) );
            allUT(:,3) = exp( sigma_d.*(allXd*beta_d) );
                              
            allCP(:,1:3,s) = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
        end
        
        Freq.MacroCash(3)    = sum( mean(allCP(:,1,:),3).*WGHT )/sum( WGHT );
        Freq.MacroCredit(3)  = sum( mean(allCP(:,2,:),3).*WGHT )/sum( WGHT );
        Freq.MacroDebit(3)   = sum( mean(allCP(:,3,:),3).*WGHT )/sum( WGHT );
        Value.MacroCash(3)   = sum( mean(allCP(:,1,:),3).*WTV )/sum( WTV );
        Value.MacroCredit(3) = sum( mean(allCP(:,2,:),3).*WTV )/sum( WTV );
        Value.MacroDebit(3)  = sum( mean(allCP(:,3,:),3).*WTV )/sum( WTV );


    % Model 5
        load results5
        beta_c  = results5( 1:num.CreMean + 1, 1);
        beta_d  = results5(num.CreMean + 2:num.base, 1);
        beta_cm = results5(num.base+ 1: num.base + num.CreRand, 1);
        beta_dm = results5(num.base + num.CreRand+ 1:end, 1);        
       
        for s = 1:num.sim
            mu_c = squeeze(mu(:, 1:num.CreRand, s));
            mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
            
            allUT      = ones(num.alltrans,3);
            allUT(:,1) = 1;
            allUT(:,2) = exp( allXc*beta_c + allXcr.*mu_c*beta_cm );
            allUT(:,3) = exp( allXd*beta_d + allXdr.*mu_d*beta_dm );
            allCP(:,1:3,s) = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
        end
        
        Freq.MacroCash(4)    = sum( mean(allCP(:,1,:),3).*WGHT )/sum( WGHT );
        Freq.MacroCredit(4)  = sum( mean(allCP(:,2,:),3).*WGHT )/sum( WGHT );
        Freq.MacroDebit(4)   = sum( mean(allCP(:,3,:),3).*WGHT )/sum( WGHT );
        Value.MacroCash(4)   = sum( mean(allCP(:,1,:),3).*WTV  )/sum( WTV  );
        Value.MacroCredit(4) = sum( mean(allCP(:,2,:),3).*WTV  )/sum( WTV  );
        Value.MacroDebit(4)  = sum( mean(allCP(:,3,:),3).*WTV  )/sum( WTV  );

        
    % Model 6
        load results6
        beta_c  = results6( 1:num.CreMean + 1, 1);
        beta_d  = results6(num.CreMean + 2:num.base, 1);
        beta_cm = results6(num.base+ 1: num.base + num.CreRand, 1);
        beta_dm = results6(num.base + num.CreRand+ 1:num.base + num.CreRand+ num.DebRand, 1);      
        tau_c   = results6(end-1,1 );        
        tau_d   = results6(end, 1);        
        
        for s = 1:num.sim
            mu_c = squeeze(mu(:, 1:num.CreRand, s));
            mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
            sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );            
            sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );            
            
            allUT      = ones(num.alltrans,3);
            allUT(:,1) = 1;
            
            allUT(:,2) = allXc*beta_c + allXcr.*mu_c*beta_cm;
            allUT(:,2) = exp( sigma_c.*allUT(:,2) );            

            allUT(:,3) = allXd*beta_d + allXdr.*mu_d*beta_dm;         
            allUT(:,3) = exp( sigma_d.*allUT(:,3) );

            allCP(:,1:3,s) = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));            
        end        
            
        Freq.MacroCash(5)    = sum( mean(allCP(:,1,:),3).*WGHT )/sum( WGHT );
        Freq.MacroCredit(5)  = sum( mean(allCP(:,2,:),3).*WGHT )/sum( WGHT );
        Freq.MacroDebit(5)   = sum( mean(allCP(:,3,:),3).*WGHT )/sum( WGHT );
        Value.MacroCash(5)   = sum( mean(allCP(:,1,:),3).*WTV  )/sum( WTV  );
        Value.MacroCredit(5) = sum( mean(allCP(:,2,:),3).*WTV  )/sum( WTV  );
        Value.MacroDebit(5)  = sum( mean(allCP(:,3,:),3).*WTV  )/sum( WTV  );

        
%%%%%%%%%%%%%%%%%%%Output LR test%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    LR = NaN(3,3);
    chi2df = LR;


    % The LR stats are in LR
    LR(1, 1) = 2*(min_fval3 - min_fval4);
    LR(1, 2) = 2*(min_fval3 - min_fval5);
    LR(1, 3) = 2*(min_fval3 - min_fval6);

    LR(2, 3) = 2*(min_fval4 - min_fval6);
    LR(3, 3) = 2*(min_fval5 - min_fval6);

    chi2df(1, 1) = -(num.param3 - num.param4);
    chi2df(1, 2) = -(num.param3 - num.param5);
    chi2df(1, 3) = -(num.param3 - num.param6);

    chi2df(2, 3) = -(num.param4 - num.param6);
    chi2df(3, 3) = -(num.param5 - num.param6);        

    % the p-values are in PVal
    PVal = 1 - chi2cdf(LR, chi2df);


    save Value Value;
    save Freq Freq;
    save PVal PVal;
    save LR LR;
        
%% Outputting the Results %%

    % Making a Estimation Results Table 
%         num.par_max        = num.base + num.mus + num.sigmas;  
%         EstRes             = zeros(num.par_max + 8, num.models*2);
% 
%         EstRes( 2:18, 1: 2) = [ min_vec1( 1:17)', StdErr1( 1:17) ];
%         EstRes(27:43, 1: 2) = [ min_vec1(18:34)', StdErr1(18:34) ];
% 
%         EstRes( 2:18, 3: 4) = [ min_vec2( 1:17)', StdErr2( 1:17) ];
%         EstRes(27:43, 3: 4) = [ min_vec2(18:34)', StdErr2(18:34) ];
% 
%         EstRes( 2:18, 5: 6) = [ min_vec3( 1:17)', StdErr3( 1:17) ];
%         EstRes(27:43, 5: 6) = [ min_vec3(18:34)', StdErr3(18:34) ];
% 
%         EstRes( 2:18, 7: 8) = [ min_vec4( 1:17)', StdErr4( 1:17) ];
%         EstRes(27:43, 7: 8) = [ min_vec4(18:34)', StdErr4(18:34) ];
%         EstRes(   25, 7: 8) = [ min_vec4(35)'   , StdErr4(35)    ];
%         EstRes(   48, 7: 8) = [ min_vec4(36)'   , StdErr4(36)    ];
% 
%         EstRes( 2:18, 9:10) = [ min_vec5( 1:17)', StdErr5( 1:17) ];
%         EstRes(27:43, 9:10) = [ min_vec5(18:34)', StdErr5(18:34) ];
%         EstRes(19:24, 9:10) = [ min_vec5(35:40)', StdErr5(35:40) ];
%         EstRes(44:47, 9:10) = [ min_vec5(41:44)', StdErr5(41:44) ];
% 
%         EstRes( 2:18,11:12) = [ min_vec6( 1:17)', StdErr6( 1:17) ];
%         EstRes(27:43,11:12) = [ min_vec6(18:34)', StdErr6(18:34) ];
%         EstRes(19:24,11:12) = [ min_vec6(35:40)', StdErr6(35:40) ];
%         EstRes(44:47,11:12) = [ min_vec6(41:44)', StdErr6(41:44) ];
%         EstRes(   25,11:12) = [ min_vec6(45),     StdErr6(45)    ];
%         EstRes(   48,11:12) = [ min_vec6(46),     StdErr6(46)    ];        
%         
%         EstRes(num.par_max+5,:) = [ InfoCri(1,1), 0, ...
%                                     InfoCri(1,2), 0, ...
%                                     InfoCri(1,3), 0, ...
%                                     InfoCri(1,4), 0, ...
%                                     InfoCri(1,5), 0, ...
%                                     InfoCri(1,6), 0 ];
% 
%         EstRes(num.par_max+6,:) = [ num.param1,   0, ...
%                                     num.param2,   0, ...
%                                     num.param3,   0, ...
%                                     num.param4,   0, ...
%                                     num.param5,   0, ...
%                                     num.param6,   0 ];
% 
%         EstRes(num.par_max+7,:) = [ InfoCri(2,1), 0, ...
%                                     InfoCri(2,2), 0, ...
%                                     InfoCri(2,3), 0, ...
%                                     InfoCri(2,4), 0, ...
%                                     InfoCri(2,5), 0, ...
%                                     InfoCri(2,6), 0 ];
% 
%         EstRes(num.par_max+8,:) = [ InfoCri(3,1), 0, ...
%                                     InfoCri(3,2), 0, ...
%                                     InfoCri(3,3), 0, ...
%                                     InfoCri(3,4), 0, ...
%                                     InfoCri(3,5), 0, ...
%                                     InfoCri(3,6), 0 ];
                                
%         EstResLbl   = [ '\tb{Credit Cards}  ' ;... % 1 
%                         ' \ \ Constant      ' ;... % 2 
%                         ' \ \ TV            ' ;... 
%                         ' \ \ TV sq         ' ;... 
%                         ' \ \ Less than $5  ' ;...
%                         ' \ \ Less than $10 ' ;...
%                         ' \ \ Grocery Store ' ;...
%                         ' \ \ Entertainment ' ;...
%                         ' \ \ Gas Station   ' ;...
%                         ' \ \ Weekday dum.  ' ;...                      
%                         ' \ \ Age           ' ;... 
%                         ' \ \ Income        ' ;...
%                         ' \ \ Ease of Use   ' ;...
%                         ' \ \ Record Keeping' ;...
%                         ' \ \ Num. of CC    ' ;... 
%                         ' \ \ Credit Reward ' ;...
%                         ' \ \ Credit Limit  ' ;...
%                         ' \ \ Revolving     ' ;... % 18
%                         ' \ \ RC for TV     ' ;... % 19
%                         ' \ \ RC for Ease   ' ;... 
%                         ' \ \ RC for Record ' ;...
%                         ' \ \ RC for Num. CC' ;... 
%                         ' \ \ RC for Rewards' ;...
%                         ' \ \ RC for C Limit' ;... % 24
%                         ' \ \ Scale for CC  ' ;... % 25
%                         '\tb{Debit Cards}   ' ;...
%                         ' \ \ Constant      ' ;... % 27
%                         ' \ \ TV            ' ;...
%                         ' \ \ TV sq         ' ;...
%                         ' \ \ Less than $5  ' ;...
%                         ' \ \ Less than $10 ' ;...
%                         ' \ \ Grocery Store ' ;...
%                         ' \ \ Entertainment ' ;...
%                         ' \ \ Gas Station   ' ;...
%                         ' \ \ Weekday dum.  ' ;...                                        
%                         ' \ \ Age           ' ;...
%                         ' \ \ Income        ' ;...
%                         ' \ \ Ease of Use   ' ;...
%                         ' \ \ Record Keeping' ;...
%                         ' \ \ Num. of DC    ' ;... 
%                         ' \ \ Low Balance   ' ;...
%                         ' \ \ Num. Free Tra.' ;...
%                         ' \ \ Debit Fee     ' ;... % 43
%                         ' \ \ RC for TV     ' ;... % 44
%                         ' \ \ RC for Ease   ' ;... 
%                         ' \ \ RC for Record ' ;...
%                         ' \ \ RC for Num DCs' ;... % 47
%                         ' \ \ Scale for DC  ' ;... % 48
%                         '                   ' ;... 
%                         'Summary Statistics ' ;... 
%                         ' \ \ No. of Param. ' ;... % 51
%                         ' \ \ Log Likelihood' ;...
%                         ' \ \ AIC           ' ;...
%                         ' \ \ BIC           ' ];   % 54

                    
%         Amp = [ ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ...
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ... 
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ... 
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ... 
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ...
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ...
%                 ' & '; ' & '; ' & '; ' & '; ' & '; ' & ';];
% 
%         Amp2 = [ ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ...
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ... 
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ... 
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ... 
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ... 
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ... 
%                  ' \\'; ' \\'; ' \\'; ' \\'; ' \\'; ' \\';];
% 
% 
%         ResultsMat = [ EstResLbl                       Amp Amp ... 
%                        num2str(EstRes(:, 1), '% 1.2f') Amp     ... 
%                        num2str(EstRes(:, 2), '% 1.2f') Amp Amp ... 
%                        num2str(EstRes(:, 3), '% 1.2f') Amp     ... 
%                        num2str(EstRes(:, 4), '% 1.2f') Amp Amp ... 
%                        num2str(EstRes(:, 5), '% 1.2f') Amp     ... 
%                        num2str(EstRes(:, 6), '% 1.2f') Amp Amp ... 
%                        num2str(EstRes(:, 7), '% 1.2f') Amp     ... 
%                        num2str(EstRes(:, 8), '% 1.2f') Amp Amp ... 
%                        num2str(EstRes(:, 9), '% 1.2f') Amp     ... 
%                        num2str(EstRes(:,10), '% 1.2f') Amp Amp ... 
%                        num2str(EstRes(:,11), '% 1.2f') Amp... 
%                        num2str(EstRes(:,12), '% 1.2f') Amp2   ];
        
        
%     % Making a Tabke fir the Fitness of the Model 
%     
%        EstResLbl2 = [ 'Frequency Share ' ;...
%                       ' \ \ \ Cash     ' ;...
%                       ' \ \ \ Credit   ' ;...
%                       ' \ \ \ Debit    ' ;...
%                       'Value Share     ' ;...
%                       ' \ \ \ Cash     ' ;...
%                       ' \ \ \ Credit   ' ;...
%                       ' \ \ \ Debit    '];
%            
%         AMP3 = [ ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & '; ' & ' ];
%         AMP4 = [ ' \\'; ' \\'; ' \\'; ' \\[3pt]'; ' \\'; ' \\'; ' \\'; ' \\' ];
%         
%         FitMat = [ EstResLbl2                   Amp Amp ... 
%                    num2str(Freq.MacroCash(1),4) Amp     ... 
%                    num2str(Freq.MacroCredit(1),4) Amp Amp ... 
%                    num2str(EstRes(:, 3),5) Amp     ... 
%                    num2str(EstRes(:, 4),4) Amp Amp ... 
%                    num2str(EstRes(:, 5),5) Amp     ... 
%                    num2str(EstRes(:, 6),4) Amp Amp ... 
%                    num2str(EstRes(:, 7),5) Amp     ... 
%                    num2str(EstRes(:, 8),4) Amp Amp ... 
%                    num2str(EstRes(:, 9),5) Amp     ... 
%                    num2str(EstRes(:,10),4) Amp Amp ... 
%                    num2str(EstRes(:,11),5) Amp... 
%                    num2str(EstRes(:,12),4) Amp2   ];
% 
%         format short g
%         disp( EstRes )
%         save EstRes EstRes
%         save ResultsMat ResultsMat
%         dlmwrite('ResultsMat.txt', ResultsMat, 'delimiter', '')
%         
%             clear opt_plus3 opt_minu3 dev_p3 dev_m3 score3 InfMat3 Avar3
%             clear opt_plus4 opt_minu4 dev_p4 dev_m4 score4 InfMat4 Avar4
%             clear opt_plus5 opt_minu5 dev_p5 dev_m5 score5 InfMat5 Avar5
%             clear opt_plus6 opt_minu6 dev_p6 dev_m6 score6 InfMat6 Avar6


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%