function [ objvalue, indLL ] = obj04( theta )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% This .m file calculate the simulated log likelihood function %%%
%%% value given the parameter 'theta.'                           %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Part(1): Some preparations for this program

    % Defining the global variables 
        global allCS allDE num W allXc allXd sigma subs
        
    % Renaming the parameters 
        beta_c = theta( 1:num.CreMean + 1)';
        beta_d = theta(num.CreMean + 2:num.base)';
        tau_c   = theta(num.base+ 1);
        tau_d   = theta(num.base + 2);
        
%% Part(2): Constructing log likelihood contribution for each individual %%
           % For more detailed for this section, see below comments. %

    % Preparation 
        indLC = zeros(num.ind,1);
        
    % Calculating the individual Likelihood contribution for S times
        for s = 1:num.sim

            % STEP-1: Making a \bar{\sigma}
                sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
                sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
                
            % STEP-1: Making a matrix of utilities
                allUT      = ones(num.alltrans,3);
                
                allUT(:,2) = exp( beta_c(1) + sigma_c.*( allXc(:, 2:end)*beta_c(2:end) ) );
                allUT(:,3) = exp( beta_d(1) + sigma_d.*( allXd(:, 2:end)*beta_d(2:end) ) );
                              
            % STEP-2: Making a matrix of Choice Probabilities
                allCP = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    
            % STEP-3: Making a vector of predicted prob. chosen in data 
                VecCP = allCP.*allDE*ones(3,1);
        
            % STEP-4: Calculating each individual loglikelihood contribution
                indLC = indLC +  accumarray(subs, VecCP,[], @prod);
                
        end
    
    
%% Part(3): Constructing objective function value %%
    
    % Step-1: Deriving each individual loglikelihood contributions
    %         (This is useful for calculating the standard errors!)
        indLL = log(indLC/num.sim);
    
    % Step-2: Summing indLL over N to calculate objective function value
        obj_s = -W'*indLL;
        check = isnan(obj_s);
        
        if check == 1
            indLL = 100000*zeros(num.ind,1);
            objvalue = 1000000;
        else
            objvalue = obj_s;
        end
                

        format shortg
        
        % CC = [ beta_c; beta_ct; tau_c ];
        % DC = [ beta_d; beta_dt; tau_d ];
        % disp( [CC DC] );
        disp( objvalue );
         
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%