function [ objvalue, indLL ] = obj06( theta )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% This .m file calculate the simulated log likelihood function %%%
%%% value given the parameter 'theta.'                           %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Part(1): Some preparations for this program

    % Defining the global variables 
        global T allCS allDE num W allXc allXd mu sigma allXcr allXdr subs
        
    % Renaming the parameters
        beta_c  = theta( 1:num.CreMean + 1)';
        beta_d  = theta(num.CreMean + 2:num.base)';
        beta_cm = theta(num.base+ 1: num.base + num.CreRand)';
        beta_dm = theta(num.base + num.CreRand+ 1:num.base + num.CreRand+ num.DebRand)';
        tau_c   = theta(end-1);
        tau_d   = theta(end);

%% Part(2): Constructing log likelihood contribution for each individual %%
           % For more detailed for this section, see below comments. %

    % Preparation 
        indLC = zeros(num.ind,1);

    % Calculating the individual Likelihood contribution for S times

        for s = 1:num.sim

            % STEP-1: Making random coeffs. in one matrix and drop one dim.
                mu_c = squeeze(mu(:, 1:num.CreRand, s));
                mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
                sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
                sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
                
            % STEP-2: Making a matrix of utilities
                allUT      = ones(num.alltrans,3);
               
                
                allUT(:,2) = allXc(:, 2:end)*beta_c(2:end) + allXcr.*mu_c*beta_cm;
                allUT(:,2) = exp( beta_c(1) + sigma_c.*allUT(:,2) );
                               
                allUT(:,3) = allXd(:, 2:end)*beta_d(2:end) + allXdr.*mu_d*beta_dm;
                allUT(:,3) = exp( beta_d(1) + sigma_d.*allUT(:,3) );
                              
            % STEP-3: Making a matrix of Choice Probabilities
                allCP = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    
            % STEP-4: Making a vector of predicted prob. chosen in data 
                VecCP = allCP.*allDE*ones(3,1);
        
            % STEP-5: Calculating each individual loglikelihood contribution
                indLC = indLC +  accumarray(subs, VecCP,[], @prod);
        
        end 

    
    
%% Part(3): Constructing objective function value %%
    
    % Step-1: Deriving each individual loglikelihood contributions
    %         (This is useful for calculating the standard errors!)
        indLL = log(indLC/num.sim);
    
    % Step-2: Summing indLL over N to calculate objective function value
        obj_s = -W'*indLL;
        check = isnan(obj_s);
        
        if check == 1
            indLL = 100000*zeros(num.ind,1);
            objvalue = 100000;
        else
            objvalue = obj_s;
        end
                

        % CC = [ beta_c; beta_cm([1:3,4:7]) ];
        % DC = [ beta_d; beta_dm([1:3,4:5]) ; 0 ; 0 ];
        % disp( [CC DC] );        
        disp( objvalue );

               
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%