function [ objvalue, indLL ] = obj08( theta )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% This .m file calculate the simulated log likelihood function %%%
%%% value given the parameter 'theta.'                           %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Part(1): Some preparations for this program

    % Defining the global variables 
        global allCS allDE num W12 allXc allXd ZC ZD ME
        
    % Renaming the parameters 
        beta_c = theta( 1:num.CreMean + 1)';
        beta_d = theta(num.CreMean + 2:num.base)';
        deltaC = theta(num.param2 + 1: num.param2 + num.acceptC )';
        deltaD = theta(num.param2 + 1 + num.acceptC : num.param8)';


%% Part(2): Constructing log likelihood contribution for each individual %%
           % For more detailed for this section, see below comments. %

    % Calculating the individual Likelihood contribution for S times

        % STEP-1: Making a matrix of utilities
            allUT      = ones(num.alltrans,3);
            allUT(:,1) = 1;
            allUT(:,2) = exp( allXc*beta_c );
            allUT(:,3) = exp( allXd*beta_d );
       
        % STEP-2: Making a matrix of Choice Probabilities
            allCP = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    
        % STEP-3: Making a vector of predicted prob. chosen in data 
            VecCP = allCP.*allDE*ones(3,1);
    
        % STEP-4: Ma
            AcceptCC = exp( ZC*deltaC )./( 1 + exp( ZC*deltaC )) ;
            AcceptDC = exp( ZD*deltaD )./( 1 + exp( ZD*deltaD )) ;
            ObsCCaccept = ( ME.C + AcceptCC - 2*ME.C*AcceptCC );
            ObsDCaccept = ( ME.D + AcceptDC - 2*ME.C*AcceptDC );
            VecAPCC = allCS(:,2).*ObsCCaccept + ...
                        ( 1 - allCS(:,2) ).*( 1 - ObsCCaccept );
            VecAPDC = allCS(:,3).*ObsDCaccept + ...
                        ( 1 - allCS(:,3) ).*( 1 - ObsDCaccept );
            
            % Some Adjustment 
            VecAPCC( allDE(:, 2) == 1   ) = 1;
            VecAPCC( allXc(:,15) < -2.2 ) = 1;
            VecAPDC( allDE(:, 3) == 1   ) = 1;
            VecAPDC( allXd(:,15) < -2.2 ) = 1;            
    
%% Part(3): Constructing objective function value %%
    
    % Step-1: Deriving each individual loglikelihood contributions
    %         (This is useful for calculating the standard errors!)
        indLL = log(VecCP.*VecAPCC.*VecAPDC);
    
    % Step-2: Summing indLL over N to calculate objective function value
        objvalue = -W12'*indLL;
        disp( objvalue );
        
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%