function [ objvalue, indLL ] = obj09( theta )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% This .m file calculate the simulated log likelihood function %%%
%%% value given the parameter 'theta.'                           %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Part(1): Some preparations for this program

    % Defining the global variables 
        global allDE num W allXc allXd subs allCSM
        
    % Renaming the parameters 
        beta_c = theta( 1:num.CreMean + 1)';
        beta_d = theta(num.CreMean + 2:num.base)';


%% Part(2): Constructing log likelihood contribution for each individual %%
    % Preparation 
        indLC = zeros(num.ind,1);

    % Calculating the individual Likelihood contribution for S times

       for s = 1:num.sim
           
        % STEP-1: Making a matrix of utilities
            allUT      = ones(num.alltrans,3);
            allUT(:,1) = 1;
            allUT(:,2) = exp( allXc*beta_c );
            allUT(:,3) = exp( allXd*beta_d );
       
        % STEP-2: Making a matrix of Choice Probabilities
            allCP = (allUT.*allCSM(:,:,s)) ./ (allUT.*allCSM(:,:,s)*ones(3,3));
    
        % STEP-3: Making a vector of predicted prob. chosen in data 
            VecCP = allCP.*allDE*ones(3,1);
        
        % STEP-5: Taking product
            indLC = indLC +  accumarray(subs, VecCP,[], @prod);

       end    
    
%% Part(3): Constructing objective function value %%
        indLL = log(indLC/num.sim);
        
    % Step-2: Summing indLL over N to calculate objective function value
        objvalue = -W'*indLL;
        disp( objvalue );
        
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




% STEP 2 Calculate the choice probabilities
% STEP 3 Calculate the likelihood contribution
% STEP 4 Averaging over S times of simulated likellihood contributions
        

%      Utilities    Choice Set   Decisions
%        1 1 6        1 1 1        1 0 0 
%        1 5 7        0 1 1        0 0 1 
%        1 9 2        1 0 0        1 0 0 
%        1 1 6        1 1 1        0 0 1
%        1 
% 
% allUT = [ 1 2 3 ; 5 2 1 ; 1 3 1 ; 1 1 4 ; 2 1 3 ];
% allDE = [ 0 1 0 ; 1 0 0 ; 0 1 0 ; 0 0 1 ; 1 0 0 ];
% allCS = [ 1 1 1 ; 1 0 0 ; 1 1 0 ; 1 1 1 ; 1 0 0 ];
% 
% allCP = (allUT.*allCS)./(allUT.*allCS*ones(3,3));
% VecCP = allCP.*allDE*ones(3,1);