% This program is written by Naoki Wakamori and Angelika Welte
% If needed, please customize directory in the following line: 
% % C:\Users\wela\Dropbox\WakamoriWelte2012\01_ProgramsAndData\03_Matlab\21_Simulation\version46
clear;



% Deciding variables included
cd ../../EstimableData
CreMean = csvread('data_CreMean.csv');
CreRand = csvread('data_CreRand.csv');
DebMean = csvread('data_DebMean.csv');
DebRand = csvread('data_DebRand.csv');

num.CreMean = size(CreMean,2);
num.CreRand = size(CreRand,2);
num.DebMean = size(DebMean,2);
num.DebRand = size(DebRand,2);

% Deciding the model
num.models =    6; % No. of Models estimated
num.sim    = 1000; % No. of Simulations
num.sigmas =    2; % No. of Scale Coefficients (\sigma)
num.base   =  num.CreMean + num.DebMean + 2 ; % No. of base parameters (\bar{\beta})
num.mus    =  num.CreRand + num.DebRand     ; % No. of Random Coefficients (\mu)

num.random = num.mus + num.sigmas;  % No. of RVs needed to generate

num.param1  = num.base;
num.param2  = num.base;
num.param9  = num.base;
num.param10  = num.base + num.sigmas;
num.param11  = num.base + num.mus;
num.param12  = num.base + num.mus + num.sigmas;




% Setting a trancation parameter
trnctn = 2.0;


%% Part(2): Loading data and Customizing the format of data %%

% Loading the data
% Loading the data
data        = csvread('data_v44ind.csv');
cd ../Simulation/version46


% Determining some variables, based on the data

% Number of individuals
num.ind      = size( unique(data(:,1)), 1 );
num.alltrans = size( data, 1);

% Number of shopping opportunities and Weights for each individual
T = zeros(num.ind,1);
W = zeros(num.ind,1);
t = 1;

for n=1:num.ind
    W(n) = data(t,4);
    T(n) = data(t,3);
    t    = t + T(n);
end


% Need to choose one of the following sets of weight
%WGHT_FIT = data(:,4)./data(:,3);
%W_TV_FIT = data(:,4).*data(:,11)./data(:,3);
%WGHT_SIM = data(:,4)./data(:,3);
%W_TV_SIM = data(:,4).*data(:,11)./data(:,3);

WGHT_FIT = data(:,4);
W_TV_FIT = data(:,4).*CreMean(:,1);
WGHT_SIM = data(:,4);
W_TV_SIM = data(:,4).*CreMean(:,1);

% Decisions that each individual made
allDE = data(:, 5: 7);

% "Percieved" Choice Set Information
allCS = data(:, 8:10);

% Transaction Characteristics

ONZ = ones(num.alltrans,1);

allXc  = [ ones(num.alltrans,1) CreMean CreRand ];
allXd  = [ ones(num.alltrans,1) DebMean DebRand ];

dummyvar = sum(reshape(allXc==1|allXc==0,size(allXc))) == size(allXc,1);
sfc = 1 ./ mean(abs(allXc));
sfc = dummyvar + (1-dummyvar) .* sfc;
allXc = allXc .* repmat(sfc,num.alltrans,1);

dummyvar = sum(reshape(allXd==1|allXd==0,size(allXd))) == size(allXd,1);
sfd = 1 ./ mean(abs(allXd));
sfd = dummyvar + (1-dummyvar) .* sfd;
allXd = allXd .* repmat(sfd,num.alltrans,1);



allXcr = allXc(:, num.CreMean+ 2:end);
allXcr_c = allXcr;
allXdr = allXd(:,num.DebMean + 2:end);
allXdr_c = allXdr;

allXc = allXc(:,1:num.CreMean + 1 );
allXd = allXd(:, 1:num.DebMean + 1);

allXc_c = allXc;
allXc_c(allXc_c(:, 15)==0, :) = min( allXc(allXc_c(:, 15 )> 0, 15)) ;
allXc_c(allXc_c(:, 17)==0, :) = min( allXc(allXc_c(:, 17 )> 0, 17)) ;

allXd_c = allXd;
allXd_c(allXd_c(:, 15)==0, :) = min( allXd(allXd_c(:, 15 )> 0, 15)) ;


allXcr_c(:,[4,6] ) = allXc_c(:, [15, 17]);
allXdr_c(:,4 ) = allXd_c(:,15);


%define a domain and subpopulation



G = {'ONZ' }  ;


%% Part(index): Generating random variables for simulations %%

% Generating random variables (scale params. and random coefficients)

% Changing the format of sigma/mu (individual to transaction)
rng(2016);

m_seed = randn(num.ind,      num.mus,    num.sim );
s_seed = randn(num.ind,      num.sigmas, num.sim );


% Truncated sigma and mu by plus/minus 2
s_seed = min(abs(s_seed), 2).*sign(s_seed);
m_seed = min(abs(m_seed), 2).*sign(m_seed);


t_ind = cumsum(accumarray(cumsum(T),1));
t_ind(2:end) = t_ind(1:end-1);
t_ind = t_ind+ 1;
mu= m_seed(t_ind, :, :);
sigma= s_seed(t_ind, :, :);
clear m_seed s_seed

save t_ind t_ind





%% Part(4): Taking Summary Statistics for the Data %%
index = 1;
i =1;
for g = G
    Frequency(i, index) = sum( allDE(:,1).*(eval(g{1}).*WGHT_FIT )/sum( (eval(g{1}).*WGHT_FIT )));
    Frequency(i + 1, index) = sum( allDE(:,2).*(eval(g{1}).*WGHT_FIT )/sum( (eval(g{1}).*WGHT_FIT )));
    Frequency(i + 2, index) = sum( allDE(:,3).*(eval(g{1}).*WGHT_FIT )/sum( (eval(g{1}).*WGHT_FIT )));
    
    VarFreq2(i,index)  =  weightedvar(allDE(:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(allDE(:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(allDE(:, 3),eval(g{1}).*WGHT_FIT);
    Value(i, index) = sum( allDE(:,1).*(eval(g{1}).*W_TV_FIT )/sum( (eval(g{1}).*W_TV_FIT )));
    Value(i + 1, index) = sum( allDE(:,2).*(eval(g{1}).*W_TV_FIT )/sum( (eval(g{1}).*W_TV_FIT )));
    Value(i + 2, index) = sum( allDE(:,3).*(eval(g{1}).*W_TV_FIT )/sum( (eval(g{1}).*W_TV_FIT )));
    
    VarValue2(i,index) =  weightedvar(allDE(:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) = weightedvar(allDE(:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) = weightedvar(allDE(:, 3),(eval(g{1}).*W_TV_FIT));
    i = i+3;
end

index = 10;
i =1;
for g = G
    Frequency(i, index) = sum( allDE(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( allDE(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( allDE(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    VarFreq2(i,index)  =  weightedvar(allDE(:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(allDE(:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  = weightedvar(allDE(:, 3),eval(g{1}).*WGHT_FIT);
    Value(i, index) = sum( allDE(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum( allDE(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( allDE(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    VarValue2(i,index) = weightedvar(allDE(:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar(allDE(:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) = weightedvar(allDE(:, 3),(eval(g{1}).*W_TV_FIT));
    %
    i = i+3;
end






%% Part(5): Simulation %%

% MODEL 3 %

load results9
random.theta9 = randn(num.param9,num.sim);
theta9        = zeros(num.param9,num.sim);
simres        = zeros(num.sim,num.alltrans,3);

% Model Fit with simulations
%         beta_c = results3( 1:14,1);
%         beta_d = results3(15:26,1);

%         allUT      = ones(num.alltrans,3);
%         allUT(:,1) = 1;
%         allUT(:,2) = exp( allXc*beta_c );
%         allUT(:,3) = exp( allXd*beta_d );
%         allCP      = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));


%simulate base line probs
simresbase = zeros(num.sim, num.alltrans, 3);

for s = 1:num.sim
    theta9(:,s) = results9(:,1) + results9(:,2).*random.theta9(:,s);
end

for s = 1:num.sim
    beta_c = theta9( 1:num.CreMean + 1, s)';
    beta_d = theta9(num.CreMean + 2:num.base,s)';
    
    allUT      = ones(num.alltrans,3);
    allUT(:,1) = 1;
    allUT(:,2) = exp( allXc*beta_c' );
    allUT(:,3) = exp( allXd*beta_d' );
    
    allCP      = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    % allCP = allUT.*OwnSet ./ (allUT.*OwnSet*ones(3,3));
    simresbase(s,:,:) = allCP;
end

simres3base = squeeze(mean(simresbase, 1));

index = 2;
i =1;
for g = G
    Frequency(i, index) = sum( simres3base(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres3base(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres3base(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    Value(i, index) = sum( simres3base(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres3base(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres3base(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    VarFreq2(i,index)  =  weightedvar(simresbase(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simresbase(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simresbase(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simresbase(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simresbase(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simresbase(:,:, 3),(eval(g{1}).*W_TV_FIT));
    %
    
    
      
    
    i = i+3;
end



% Counterfactual Simulation


for s = 1:num.sim
    beta_c = theta9( 1:num.CreMean + 1, s)';
    beta_d = theta9(num.CreMean + 2:num.base,s)';
    
    allUT      = ones(num.alltrans,3);
    allUT(:,1) = 1;
    allUT(:,2) = exp( allXc_c*beta_c' );
    allUT(:,3) = exp( allXd_c*beta_d' );
    
    allCP      = allUT ./ (allUT*ones(3,3));
    simres(s,:,:) = allCP;
end


simresdiff = simresbase - simres;
simres3 = squeeze(mean(simres, 1));
simres3diff = squeeze(mean(simresdiff, 1));

index = 3;


i =1;
for g = G
    Frequency(i, index) = sum( simres3(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres3(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres3(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    Value(i, index) = sum( simres3(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres3(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres3(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    
    VarFreq2(i,index)  =  weightedvar(simres(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simres(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simres(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simres(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simres(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simres(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    
    
    
    FrequencyDiff(i, index) = sum( simres3diff(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 1, index) = sum( simres3diff(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 2, index) = sum( simres3diff(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    ValueDiff(i, index) = sum( simres3diff(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 1, index) = sum(simres3diff(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 2, index) = sum( simres3diff(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    VarFreq2Diff(i,index)  =  weightedvar(simresdiff(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+1,index)  =  weightedvar(simresdiff(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+2,index)  =  weightedvar(simresdiff(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2Diff(i,index) =  weightedvar( simresdiff(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+1,index) =  weightedvar( simresdiff(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+2,index) =  weightedvar( simresdiff(:,:, 3),(eval(g{1}).*W_TV_FIT));
    %
    
    i = i+3;
end








clear results9 theta9 random simres simres3
disp( 'Finish simulations for Model 9' )





% MODEL 4 %
load results10

random.theta10 = randn(num.param10,num.sim);

theta4        = zeros(num.param10,num.sim);
simres        = zeros(num.sim,num.alltrans,3);
allCP         = zeros(num.alltrans,3,num.sim);

beta_c = results10( 1:num.CreMean + 1, 1);
beta_d = results10(num.CreMean + 2:num.base, 1);
tau_c = 0;
tau_d = 0;
if  ( abs(results10(num.base+ 1, 1)) - 1.96*(abs(results10(num.base+ 1, 2))) > 0)
    
    tau_c   = results10(num.base+ 1, 1);
end


if  ( abs(results10(num.base+ 2, 1)) - 1.96*(abs(results10(num.base+ 2, 2))) > 0)
    
    tau_d   = results10(num.base + 2, 1);
end



% Model Fit
for s = 1:num.sim
    % STEP-1: Making a \bar{\sigma}
    sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
    sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    
    allUT(:,2) = exp( beta_c(1) + sigma_c.*( allXc(:, 2:end)*beta_c(2:end) ) );
    allUT(:,3) = exp( beta_d(1) + sigma_d.*( allXd(:, 2:end)*beta_d(2:end) ) );
    
    % STEP-2: Making a matrix of Choice Probabilities
    allCP = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    
    
    simresbase(s,:,:) = allCP;
end

simres4base = squeeze(mean(simresbase, 1));

index = 4;
i =1;
for g = G
    Frequency(i, index) = sum( simres4base(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres4base(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres4base(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    Value(i, index) = sum( simres4base(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres4base(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres4base(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    VarFreq2(i,index)  =  weightedvar(simresbase(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simresbase(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simresbase(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simresbase(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simresbase(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simresbase(:,:, 3),(eval(g{1}).*W_TV_FIT));
    VarFreq2Diff(i,index)  =  weightedvar(simresdiff(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+1,index)  =  weightedvar(simresdiff(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+2,index)  =  weightedvar(simresdiff(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2Diff(i,index) =  weightedvar( simresdiff(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+1,index) =  weightedvar( simresdiff(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+2,index) =  weightedvar( simresdiff(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    i = i+3;
end

% Simulation

for s = 1:num.sim
    theta4(:,s) = results10(:,1) + results10(:,2).*random.theta10(:,s);
end

for s = 1:num.sim
    beta_c = theta4( 1:num.CreMean + 1, s);
    beta_d = theta4(num.CreMean + 2:num.base, s);
    tau_c = results10(num.base+ 1, 1);
    tau_d = results10(num.base+ 2, 1);
    if  ( abs(results10(num.base+ 1, 1)) - 1.96*(abs(results10(num.base+ 1, 2))) > 0)
        
        tau_c   = theta4(num.base+ 1, s);
    end
    
    if  ( abs(results10(num.base+ 2, 1)) - 1.96*(abs(results10(num.base+ 2, 2))) > 0)
        
        tau_d  = theta4(num.base + 2, s);
    end
    
    
    sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
    sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    allUT(:,2) = exp( beta_c(1) + sigma_c.*( allXc(:, 2:end)*beta_c(2:end) ) );
    allUT(:,3) = exp( beta_d(1) + sigma_d.*( allXd(:, 2:end)*beta_d(2:end) ) );
    
    % STEP-2: Making a matrix of Choice Probabilities
    allCP = (allUT) ./ (allUT*ones(3,3));
    % allCP = allUT.*OwnSet ./ (allUT.*OwnSet*ones(3,3));
    
    simres(s,:,:) = allCP;
end
% save simres simres

simresdiff = simresbase - simres;
simres4 = squeeze(mean(simres, 1));
simres4diff = squeeze(mean(simresdiff, 1));

index = 5;

i =1;
for g = G
    Frequency(i, index) = sum( simres4(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres4(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres4(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    Value(i, index) = sum( simres4(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres4(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres4(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    VarFreq2(i,index)  =  weightedvar(simres(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simres(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simres(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simres(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simres(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simres(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    
    FrequencyDiff(i, index) = sum( simres4diff(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 1, index) = sum( simres4diff(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 2, index) = sum( simres4diff(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    ValueDiff(i, index) = sum( simres4diff(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 1, index) = sum(simres4diff(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 2, index) = sum( simres4diff(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    VarFreq2Diff(i,index)  =  weightedvar(simresdiff(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+1,index)  =  weightedvar(simresdiff(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+2,index)  =  weightedvar(simresdiff(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2Diff(i,index) =  weightedvar( simresdiff(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+1,index) =  weightedvar( simresdiff(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+2,index) =  weightedvar( simresdiff(:,:, 3),(eval(g{1}).*W_TV_FIT));
    i = i+3;
end


clear results4 theta4 random simres simres4
disp( 'Finish simulations for Model 10' )







% MODEL 5 % %
load results11





random.theta5 = randn(num.param11,num.sim);
theta5        = zeros(num.param11,num.sim);
simres        = zeros(num.sim,num.alltrans,3);
allCP         = zeros(num.alltrans,3,num.sim);




beta_c = results11( 1:num.CreMean + 1, 1);
beta_d = results11(num.CreMean + 2:num.base, 1);
beta_cm = results11(num.base+ 1: num.base + num.CreRand, 1);
beta_dm = results11(num.base + num.CreRand+ 1:end, 1);



% Model Fit

for s = 1:num.sim
    % STEP-1: Making random coeffs. in one matrix and drop one dim.
    mu_c = squeeze(mu(:, 1:num.CreRand, s));
    mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    
    allUT(:,2) = exp( allXc*beta_c + allXcr.*mu_c*beta_cm );
    allUT(:,3) = exp( allXd*beta_d + allXdr.*mu_d*beta_dm );
    
    
    allCP(:,:,s) = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    simresbase(s,:,:) = allCP(:, :, s);
end

simres5base = squeeze(mean(simresbase, 1));

index = 6;
i =1;
for g = G
    Frequency(i, index) = sum( simres5base(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres5base(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres5base(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    Value(i, index) = sum( simres5base(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres5base(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres5base(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    VarFreq2(i,index)  =  weightedvar(simresbase(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simresbase(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simresbase(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simresbase(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simresbase(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simresbase(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    
    i = i+3;
end

% Simulation

for s = 1:num.sim
    theta5(:,s) = results11(:,1) + results11(:,2).*random.theta5(:,s);
end

for s = 1:num.sim
    beta_c = theta5( 1:num.CreMean + 1, s);
    beta_d = theta5(num.CreMean + 2:num.base, s);
    beta_cm = results11(num.base+ 1: num.base + num.CreRand, 1);
    beta_dm = results11(num.base + num.CreRand+ 1:end, 1);
    for i = num.base+1 : (num.base + num.CreRand)
        
        if   ( abs(results11(i, 1)) - 1.96*(abs(results11(i, 2))) > 0)
            
            beta_cm( i - num.base)  = theta5(i, s);
            
        end
        
    end
    
    
    for i = (num.base + num.CreRand + 1): (num.base + num.CreRand + num.DebRand)
        
        if   ( abs(results11(i, 1)) - 1.96*(abs(results11(i, 2))) > 0)
            
            beta_dm( i - num.base - num.CreRand) = theta5(i, s);
            
        end
        
    end
    % STEP-1: Making random coeffs. in one matrix and drop one dim.
    mu_c = squeeze(mu(:, 1:num.CreRand, s));
    mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    
    allUT(:,2) = exp( allXc_c*beta_c + allXcr_c.*mu_c*beta_cm );
    allUT(:,3) = exp( allXd_c*beta_d + allXdr_c.*mu_d*beta_dm );
    % allCP = allUT.*OwnSet ./ (allUT.*OwnSet*ones(3,3));
    allCP      = allUT ./ (allUT*ones(3,3));
    
    simres(s,:,:) = allCP;
end
% save simres simres

simresdiff = simresbase - simres;
simres5 = squeeze(mean(simres, 1));
simres5diff = squeeze(mean(simresdiff, 1));

index = 7;

i =1;
for g = G
    Frequency(i, index) = sum( simres5(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres5(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres5(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    Value(i, index) = sum( simres5(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres5(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres5(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    VarFreq2(i,index)  =  weightedvar(simres(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simres(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simres(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simres(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simres(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simres(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    FrequencyDiff(i, index) = sum( simres5diff(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 1, index) = sum( simres5diff(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 2, index) = sum( simres5diff(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    ValueDiff(i, index) = sum( simres5diff(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 1, index) = sum(simres5diff(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 2, index) = sum( simres5diff(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    
    VarFreq2Diff(i,index)  =  weightedvar(simresdiff(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+1,index)  =  weightedvar(simresdiff(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+2,index)  =  weightedvar(simresdiff(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2Diff(i,index) =  weightedvar( simresdiff(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+1,index) =  weightedvar( simresdiff(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+2,index) =  weightedvar( simresdiff(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    
    
    i = i+3;
end


clear results11 theta5 random simres simres5
disp( 'Finish simulations for Model 11' )



% MODEL 6 % %
load results6





random.theta6 = randn(num.param12,num.sim);
theta6        = zeros(num.param12,num.sim);
simres        = zeros(num.sim,num.alltrans,3);
allCP         = zeros(num.alltrans,3,num.sim);




beta_c  = results12( 1:num.CreMean + 1, 1);
beta_d  = results12(num.CreMean + 2:num.base, 1);



beta_cm = results12(num.base+ 1: num.base + num.CreRand, 1);
beta_dm = results12(num.base + num.CreRand+ 1:num.base + num.CreRand+ num.DebRand, 1);
tau_c   = results12(end-1, 1);
tau_d   = results12(end, 1);






% Model Fit

for s = 1:num.sim
    
    % STEP-1: Making random coeffs. in one matrix and drop one dim.
    mu_c = squeeze(mu(:, 1:num.CreRand, s));
    mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
    sigma_c = exp( -0.5*tau_c^2 - tau_c*sigma(:,1,s) );
    sigma_d = exp( -0.5*tau_d^2 - tau_d*sigma(:,2,s) );
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    allUT(:,2) = allXc(:, 2:end)*beta_c(2:end) + allXcr.*mu_c*beta_cm;
    allUT(:,2) = exp( beta_c(1) + sigma_c.*allUT(:,2) );
    
    allUT(:,3) = allXd(:, 2:end)*beta_d(2:end) + allXdr.*mu_d*beta_dm;
    allUT(:,3) = exp( beta_d(1) + sigma_d.*allUT(:,3) );
    
    
    
    
    allCP(:,:,s) = (allUT.*allCS) ./ (allUT.*allCS*ones(3,3));
    simresbase(s,:,:) = allCP(:, :, s);
end

simres6base = squeeze(mean(simresbase, 1));

index = 8;
i =1;
for g = G
    Frequency(i, index) = sum( simres6base(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres6base(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres6base(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    Value(i, index) = sum( simres6base(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres6base(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres6base(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    VarFreq2(i,index)  =  weightedvar(simresbase(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simresbase(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simresbase(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simresbase(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simresbase(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simresbase(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    i = i+3;
end

% Simulation

for s = 1:num.sim
    theta6(:,s) = results12(:,1) + results12(:,2).*random.theta6(:,s);
end

for s = 1:num.sim
    beta_c  = theta6( 1:num.CreMean + 1, s);
    beta_d  = theta6(num.CreMean + 2:num.base,s);
    
    
    
    beta_cm = results12(num.base+ 1: num.base + num.CreRand, 1);
    beta_dm = results12(num.base + num.CreRand+ 1:num.base + num.CreRand+ num.DebRand, 1);
    tau_c   = results12(end-1, 1);
    tau_d   = results12(end, 1);
    %drop insignificant random coefficients
    for i = num.base+1 : (num.base + num.CreRand)
        
        if   ( abs(results12(i, 1)) - 1.96*(abs(results12(i, 2))) > 0)
            
            beta_cm( i - num.base)  = theta6(i, s);
            
        end
        
    end
    
    
    for i = (num.base + num.CreRand + 1): (num.base + num.CreRand + num.DebRand)
        
        if   ( abs(results12(i, 1)) - 1.96*(abs(results12(i, 2))) > 0)
            
            beta_dm( i - num.base - num.CreRand) = theta6(i, s);
            
        end
        
    end
    
    
    
    
    
    
    if  ( abs(results12(end-1, 1)) - 1.96*(abs(results12(end-1, 2))) > 0)
        
        tau_c   = theta6(num.base+ 1, s);
    end
    
    if  ( abs(results12(end, 1)) - 1.96*(abs(results12(end, 2))) > 0)
        
        tau_d  = theta6(end, s);
    end
    
    
    % STEP-1: Making random coeffs. in one matrix and drop one dim.
    mu_c = squeeze(mu(:, 1:num.CreRand, s));
    mu_d = squeeze(mu(:, num.CreRand + 1 : num.CreRand + num.DebRand,s));
    
    % STEP-1: Making a matrix of utilities
    allUT      = ones(num.alltrans,3);
    allUT(:,2) = allXc(:, 2:end)*beta_c(2:end) + allXcr.*mu_c*beta_cm;
    allUT(:,2) = exp( beta_c(1) + sigma_c.*allUT(:,2) );
    
    allUT(:,3) = allXd(:, 2:end)*beta_d(2:end) + allXdr.*mu_d*beta_dm;
    allUT(:,3) = exp( beta_d(1) + sigma_d.*allUT(:,3) );
    
    
    
    
    
    allCP      = allUT ./ (allUT*ones(3,3));
    
    simres(s,:,:) = allCP;
end
% save simres simres

simresdiff = simresbase - simres;
simres6 = squeeze(mean(simres, 1));
simres6diff = squeeze(mean(simresdiff, 1));

index = 9;

i =1;
for g = G
    Frequency(i, index) = sum( simres6(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 1, index) = sum( simres6(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    Frequency(i + 2, index) = sum( simres6(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    Value(i, index) = sum( simres6(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 1, index) = sum(simres6(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    Value(i + 2, index) = sum( simres6(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    VarFreq2(i,index)  =  weightedvar(simres(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+1,index)  =  weightedvar(simres(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2(i+2,index)  =  weightedvar(simres(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2(i,index) =  weightedvar( simres(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+1,index) =  weightedvar( simres(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2(i+2,index) =  weightedvar( simres(:,:, 3),(eval(g{1}).*W_TV_FIT));
    
    
    FrequencyDiff(i, index) = sum( simres6diff(:,1).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 1, index) = sum( simres6diff(:,2).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    FrequencyDiff(i + 2, index) = sum( simres6diff(:,3).*(eval(g{1}).*WGHT_SIM )/sum( (eval(g{1}).*WGHT_SIM )));
    
    
    
    ValueDiff(i, index) = sum( simres6diff(:,1).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 1, index) = sum(simres6diff(:,2).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    ValueDiff(i + 2, index) = sum( simres6diff(:,3).*(eval(g{1}).*W_TV_SIM )/sum( (eval(g{1}).*W_TV_SIM )));
    
    
    
    
    VarFreq2Diff(i,index)  =  weightedvar(simresdiff(:,:, 1),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+1,index)  =  weightedvar(simresdiff(:,:, 2),eval(g{1}).*WGHT_FIT);
    VarFreq2Diff(i+2,index)  =  weightedvar(simresdiff(:,:, 3),eval(g{1}).*WGHT_FIT);
    
    VarValue2Diff(i,index) =  weightedvar( simresdiff(:,:,1),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+1,index) =  weightedvar( simresdiff(:,:,2),(eval(g{1}).*W_TV_FIT));
    VarValue2Diff(i+2,index) =  weightedvar( simresdiff(:,:, 3),(eval(g{1}).*W_TV_FIT));
    i = i+3;
end


clear results12 theta6 random simres simres6
disp( 'Finish simulations for Model 12' )



index = [1, 2,4]    ;
%% Displaying the results in TeX format %%
ModelFit = zeros(8, size(index, 2), size(Frequency,1)/3);
for i = 1:size(Frequency,1)/3
    ModelFit( :,:, i)      = zeros(8,size(index, 2));
    ModelFit( 2,:, i) =  Frequency(3*(i-1)+ 1,index ) ;
    ModelFit( 3,:, i) = Frequency(3*(i-1)+ 2, index);
    ModelFit(4,:, i) = Frequency(3*(i-1)+ 3, index );
    ModelFit(6,:, i) =Value(3*(i-1)+ 1, index ) ;
    ModelFit(7,:, i) =Value(3*(i-1)+ 2, index ) ;
    ModelFit(8,:, i) = Value(3*(i-1)+ 3,index ) ;
end




SimRes      = zeros(8,5, size(Frequency,1)/3);
Fit      = zeros(8,5, size(Frequency,1)/3);

%VarSimRes= zeros(8,5, size(Frequency,1)/3);

VarSimRes2= zeros(8,5, size(Frequency,1)/3);

for i = 1:size(Frequency,1)/3
    
    
    
    
    
    
    for j = 1:3
        SimRes(j+1,:, i) = [ 100*Frequency((i - 1)*3 + j, 10) ...
            100*( Frequency((i - 1)*3 + j, 3)-Frequency((i - 1)*3 + j, 2) ) ...
            100*( Frequency((i - 1)*3 + j, 5)-Frequency((i - 1)*3 + j, 4) ) ...
            100*( Frequency((i - 1)*3 + j, 7)-Frequency((i - 1)*3 + j,6) ) ...
            100*( Frequency((i - 1)*3 + j, 9)-Frequency((i - 1)*3 + j, 8) )     ];
        
        
        Fit(j+1,:, i) = [ 100*Frequency((i - 1)*3 + j, 10) ...
            100*( Frequency((i - 1)*3 + j, 2) ) ...
            100*( Frequency((i - 1)*3 + j, 4) ) ...
            100*( Frequency((i - 1)*3 + j, 6) ) ...
            100*( Frequency((i - 1)*3 + j, 8) )     ];
        
        
        
        VarSimRes2(j+1,:, i) = [ 10000*VarFreq2Diff((i - 1)*3 + j, 1) ...
            10000*( VarFreq2Diff((i - 1)*3 + j, 3) ) ...
            10000*(VarFreq2Diff((i - 1)*3 + j, 5) ) ...
            10000*( VarFreq2Diff((i - 1)*3 + j, 7) ) ...
            10000*( VarFreq2Diff((i - 1)*3 + j, 9) )     ];
        
        SimRes(j+5,:, i) = [ 100*Value((i - 1)*3 + j, 10) ...
            100*( Value((i - 1)*3 + j, 3)-Value((i - 1)*3 + j, 2) ) ...
            100*( Value((i - 1)*3 + j, 5)-Value((i - 1)*3 + j, 4) ) ...
            100*( Value((i - 1)*3 + j, 7)-Value((i - 1)*3 + j,6) ) ...
            100*( Value((i - 1)*3 + j, 9)-Value((i - 1)*3 + j, 8) )     ];
        
        Fit(j+5,:, i) = [ 100*Value((i - 1)*3 + j, 10) ...
            100*( Value((i - 1)*3 + j, 2) ) ...
            100*( Value((i - 1)*3 + j, 4) ) ...
            100*( Value((i - 1)*3 + j, 6) ) ...
            100*( Value((i - 1)*3 + j, 8) )     ];
        
        
        
        VarSimRes2(j+5,:, i) = [ 10000*( VarValue2Diff((i - 1)*3 + j, 1) ) ...
            10000*( VarValue2Diff((i - 1)*3 + j, 3) ) ...
            10000*(VarValue2Diff((i - 1)*3 + j, 5) ) ...
            10000*( VarValue2Diff((i - 1)*3 + j, 7) ) ...
            10000*( VarValue2Diff((i - 1)*3 + j, 9) )     ];
        
        
        
        
    end
    
    
end


Fit46 = num2cell(Fit);
S = num2cell(SimRes);


STD_S2 = num2cell(sqrt(VarSimRes2));

Freq = num2cell(Frequency);
Val = num2cell(Value);
c  = cellstr(G);
i =1;
for g = G
    Fit46(1, 1, i) = c(i);
    S(1,1, i) = c(i);
    % STD_S(1,1,i) = c(i);
    STD_S2(1,1,i) = c(i);
    i = i+ 1;
    
end

dlmcell('Sout46.txt',S)

dlmcell('SDout46.txt',  STD_S2)
dlmcell('Fit46.txt', Fit46)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END OF M FILE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%