//////// READ ME - HOW TO RUN THIS PROGRAM  ////////
//                                                //
// (1) Obtain the following three data files:     //
//      1) 09-021804-01sq-postclean.dta           //
//      2) 09-021804-01dsi-postclean.dta          //
//      3) rewards.dta                            //
// (2) If needed, customize line 27 for your own  //
//     environment and put three data files there //
// (3) After run this program, you will obtain    //
//     several csv files in the same folder that  //
//     are used for running some .m files in      //
//     the subfolders of MatlabCodes. So, please  //  
//     cut and paste them to there.               // 
//                                                //
// This do file is programmed by Naoki Wakamori   // 
// and Angelika Welte. If you have any questions, //
// please email us at nwakamo@gmail.com           //
//       										  //
//                   Last Update : June 2, 2016	  //
//                                                //
////////////////////////////////////////////////////
clear matrix
clear
set more off
set scheme s1mono
set memory 1000M
*cd "customize this part for your environment, if needed"

//////////////////////////////////////////////
// PART I. Data Cleaning - Demographic Data //
//////////////////////////////////////////////

* Loading SQ data 
	use 09-021804-01sq-postclean.dta

* Keep the samples who answered DSI
	keep if wdsicap != .

* Creating some variables
	generate gender = qa - 1
	generate age    = 2009 - qb
	generate income = qc1
	generate num_cc = q2_1
	generate num_dc = q2_2
	generate d_fee  = q7
	generate free_n = q8
	generate c_limit = q13
	
	* Age Category *
    generate age1 = 0 
    generate age2 = 0 
    replace  age1 = 1 if age < 35
    replace  age2 = 1 if age > 54

	* Income Category *
    generate incomecat = 0	  
    replace  incomecat = 1 if (income==1)|(income==2)
    replace  incomecat = 2 if (income==3)|(income==4)|(income==5)
    replace  incomecat = 3 if (income==6)|(income==7)|(income==8)
    replace  incomecat = 4 if (income==9)|(income==10)
	  
	* Low Balance (Bank Account) Dummy *
	generate LowBalance = 0
	replace  LowBalance = 1 if (q9_2 == 1)
	
	* Credit Card Balance Dummy *
	generate OwingLastMonth = 0 
	replace  OwingLastMonth = 1 if (q17 != 1)
	replace  OwingLastMonth = 0 if (num_cc == 0)
	
	* Revolver Dummy * 
	generate NonRevol = 0
	replace  NonRevol = 0 if (q18 == 1)&(num_cc > 0)

	* Credit Limit * 
	replace c_limit = 0 if (q13==.)&(num_cc==0)

	* Attitudinal Data * 
	generate ease_de = log(q23_2/q23_1) if (q23_2!=6)&(num_dc>0)
	generate ease_cr = log(q23_4/q23_1) if (q23_4!=6)&(num_cc>0)
	generate keep_de = log(q24_2/q24_1) if (q24_2!=6)&(num_dc>0)
	generate keep_cr = log(q24_3/q24_1) if (q24_3!=6)&(num_cc>0)
	replace  ease_cr = 0 if (num_cc == 0)&(ease_cr==.)
	replace  keep_cr = 0 if (num_cc == 0)&(keep_cr==.)
	replace  ease_de = 0 if (num_dc == 0)&(ease_de==.)
	replace  keep_de = 0 if (num_dc == 0)&(keep_de==.)
	
	* Dummies for Credit/Debit/Cash Never users *
	gen cre_never = 0
	gen deb_never = 0
	gen cas_never = 0 
	replace cas_never = 1 if q22_1_1 != . & q22_1_1 == 0	  
	replace cas_never = 1 if q22_2_1 != . & q22_2_1 == 0	  	  
	replace cas_never = 1 if q22_1   != . & q22_1   == 2
	replace cre_never = 1 if q22_1_3 != . & q22_1_3 == 0	  
	replace cre_never = 1 if q22_2_3 != . & q22_2_3 == 0	  	  
	replace cre_never = 1 if q22_3   != . & q22_3   == 2
	replace deb_never = 1 if q22_1_2 != . & q22_1_2 == 0
	replace deb_never = 1 if q22_2_2 != . & q22_2_2 == 0	  
	replace deb_never = 1 if q22_2   != . & q22_2   == 2 	  	  

	* Dropping some samples which have missing information * 
	drop if (c_limit == 8)|(c_limit == .)
	drop if q23_1 == 6 | q24_1 == 6	
	drop if (ease_cr==.)|(ease_de==.)|(keep_de==.)|(keep_cr==.)
	
* Finishing data cleaning and saving as as demographic data sheet
	sort idnumber
	save demotemp.dta, replace
	  
	  
/////////////////////////////////////////////////
// PART II. Data Cleaning - Transactional Data //
/////////////////////////////////////////////////
  
* Loading DSI data
	use 09-021804-01dsi-postclean.dta, clear

* Merging three data-sets: SQ, DSI, and Rewards
	merge m:1 idnumber using demotemp.dta
	drop  _merge
	erase demotemp.dta
	merge m:1 idnumber using rewards.dta
	drop _merge	  

* Assigning sample weights 	
	svyset idnumber [pweight = wdsicap]

* Drop some transaction data that are conducted by people who only took SQ,
* as we need to know both information to estimate the model
	drop if wdsicap == .
	  
* Creating the maximum number of transactions per respondent
	bysort idnumber: egen t_num_max = max(transnum)

	  
* Dropping some transactions by the following criteria: 

	*1. if transaction value is zero or missing
	drop  if t5 == .
	drop  if t5 == 0

	*2. if actual method of payment is missing
	drop  if (t8_1==.)&(t8_2==.)&(t8_3==.)&(t8_4==.)&(t8_5==.)
			
	*3. if method of payment are multiple
	generate t8t = t8_1 + t8_2/2 + t8_3/3 + t8_4/4 + t8_5/5
	drop  if t8t != 1
		
	*4. if methods of payment are cheques and/or store-valued cards 
	generate method_of_payment = t8_1 + t8_2+ t8_3 + t8_4 + t8_5
	drop if (method_of_payment == 4)|(method_of_payment == 5)
	drop method_of_payment

	*5. if acceptance is missing or do not know
	*   (We also create Figure A2 to verify the transaction value 
	*    distribution are not different for remaining samples and
	*    dropped samples)
	replace t11_6 = 6 if t11_6 == . 
	tab t11_6, mi
	twoway (kdensity t5 if (t5<200)&(t5>0)&(t11_6==6) [aweight = wdsicap], ///
		   width(5) lcolor(black) lwidth(0.325)) ///
		   (kdensity t5 if t5<200 & (t5>0) &t11_6 ==0 [aweight = wdsicap], ///
		   width(5) lcolor(blue) lwidth(0.5) lstyle(p2) ), ///
		   xtitle(Transaction Value) ytitle(Density) xlabel(0(25)200) ///
		   legend(label(1 "do NOT know accpetance") label(2 "Know acceptance"))
		   graph export "FigA1.eps", as(eps) preview(off) replace			
	tab t6b t11_6, row 
	drop if t11_6 == . | t11_6 == 6
			
	*6. if observed choice is inconsistent with their decisions
	gen d_cash   = t8_1
	gen d_credit = t8_2/2
	gen d_debit  = t8_3/3
	gen cash     = 1 - t11_1
	gen credit   = 1 - t11_2/2
	gen debit    = 1 - t11_3/3 
	gen credit2 = credit
	gen debit2 = debit
	drop if (d_cash==1)&(cash==0)
	drop if (d_debit==1)&(debit==0)
	drop if (d_credit==1)&(credit==0)
	drop if (num_cc==0)&(d_credit==1)
	drop if (num_dc==0)&(d_debit==1)			

	*7. if transaction value exceeds 300CAD
	drop if t5 > 300
	
	*7.5 Investigating where cash was not accepted
	tab t6a cash, mi 
		*  210 transactions did not accept cash and 11 by mail, 
		*  19 by phone and 134 by online. Therefore, we further
		*  investigate for remaining 46 transactions below 
		tab ot6a t7 if cash == 0 & t6a == 2 
		tab ot6a t7 if cash == 0 & t6a == 5
		tab ot6a t7 if cash == 0 & t6a == 6
		tab ot6a t7 if cash == 0 & ( (t6a==2)|(t6a==5)|(t6a==6)) 
		tab t7 ot6a if cash == 0 & ( (t6a==2)|(t6a==5)|(t6a==6)) 
		*  In the end, we dropped transaction made through 
		* mail, phone and online first, and then dropped 
		* transaction that did not accept cash 
		drop if (t6a==1)|(t6a==3)|(t6a==4)
		drop if cash == 0

* Creating some variables for estimation 
	generate tv    = t5
	generate tv_sq = t5^2
	generate register = t6b
	generate groc_dum = 0 
	generate ente_dum = 0
	generate gas_dum  = 0 
    generate age_sq   = age^2
	generate decision = 0 + 2*d_credit + d_debit

	replace groc_dum = 1 if t7 == 1
	replace gas_dum  = 1 if t7 == 2
	replace ente_dum = 1 if t7 == 8			
	replace rewards = 0 if rewards == .
	replace credit = 0  if num_cc == 0
	replace debit  = 0  if num_dc == 0
	
* Sorting and re-Counting the number of shopping trips for each respondent
* Basically, to extract individual fixed effect, we need to have at least 
* three transactions per respondent. So, we dropped those people who had 
* less than three transactions. We again checked the transaction value 
* distribution and other dimensions (See APPENDIX A). Figure A2 is 
* generated here. 
	sort idnumber transnum
	by idnumber:  gen transnum2 = _n
	by idnumber: egen transnum3 = max(transnum2)
	
	* The following two commands creat the left part of Table 2
	tab transnum3 if transnum2 == 1
	svy: tab transnum3 if transnum2 == 1

	* First creat the drop indicator so that we can creat Figure A2
	generate drop_obs = 0
	replace  drop_obs = 1 if transnum3 < 3
	twoway (kdensity t5 if (t5<200)&(drop_obs==0) [aweight = wdsicap], ///
			width(5) lcolor(black) lwidth(0.325)) ///
		   (kdensity t5 if (t5<200)&(drop_obs==1) ///
		   [aweight = wdsicap], ///
		   width(5) lcolor(blue) lwidth(0.5) lstyle(p2) ), ///
		   xtitle(Transaction Value) ytitle(Density) xlabel(0(25)200) ///
		   legend(label(1 "Remaining Observations") ///
		   label(2 "Dropped Observations"))			
	graph export "FigA2.eps", as(eps) preview(off) replace
			
	drop if transnum3 < 3
	sort idnumber transnum2
	drop transnum2 transnum3
	by idnumber:  gen transnum2 = _n
	by idnumber: egen transnum3 = max(transnum2) 
	svyset idnumber [pw =  wdsicap]

* Dropping useless information
	drop daynum t3 t4 t5 t8* t7_* week t6bo method
	drop ot8_1 ot8_2 t6a_* ot11 t9 t12 

	
		
///////////////////////////////////////////////
// PART III. Providing the numbers in Tables //
///////////////////////////////////////////////

		
* Table 2 (after trancation) 
	tab transnum3 if transnum2 == 1 
	svy: tab transnum3 if transnum2 == 1

* Creating indicator for individual payment types	
	sort idnumber
	by idnumber:  gen num_ca1 = sum(d_cash)
	by idnumber: egen num_ca  = max(num_ca1)
	by idnumber:  gen num_cr1 = sum(d_credit)
	by idnumber: egen num_cr  = max(num_cr1)
	by idnumber:  gen num_de1 = sum(d_debit)
	by idnumber: egen num_de  = max(num_de1)
	drop num_cr1 num_ca1 num_de1

	generate pay_type =  0
	replace  pay_type =  1 if (num_de==0)&(num_cr==0)
	replace  pay_type = 11 if (num_ca==0)&(num_de >0)&(num_cr==0)
	replace  pay_type = 12 if (num_ca >0)&(num_de >0)&(num_cr==0)
	replace  pay_type = 21 if (num_ca==0)&(num_de==0)&(num_cr >0)
	replace  pay_type = 22 if (num_ca >0)&(num_de==0)&(num_cr >0)
	replace  pay_type = 31 if (num_ca==0)&(num_de >0)&(num_cr >0)
	replace  pay_type = 32 if (num_ca >0)&(num_de >0)&(num_cr >0)

	generate pay_type2 = 0
	replace  pay_type2 = 1 if (pay_type==1)
	replace  pay_type2 = 2 if (pay_type==11)|(pay_type==12)
	replace  pay_type2 = 3 if (pay_type==21)|(pay_type==22)
	replace  pay_type2 = 4 if (pay_type==31)|(pay_type==32)

	label define ptype2 1 "Cash Users" 2 "Debit Users" ///
	                    3 "Credit Users" 4 "Mixed Users"
	label values pay_type2 ptype2 	


* Table 3 Panel A 
	tab pay_type if (transnum2==1)		
	svy: tab pay_type if (transnum2==1)		
	svy: mean transnum3 if pay_type == 1  & transnum2 == 1
	svy: mean transnum3 if pay_type == 11 & transnum2 == 1
	svy: mean transnum3 if pay_type == 12 & transnum2 == 1
	svy: mean transnum3 if pay_type == 21 & transnum2 == 1
	svy: mean transnum3 if pay_type == 22 & transnum2 == 1
	svy: mean transnum3 if pay_type == 31 & transnum2 == 1
	svy: mean transnum3 if pay_type == 32 & transnum2 == 1
	svy: mean tv if pay_type == 1
	svy: mean tv if pay_type == 11
	svy: mean tv if pay_type == 21
	svy: mean tv if pay_type == 22
	svy: mean tv if pay_type == 31
	svy: mean tv if pay_type == 32

* Table 3 Panel B
	svy: tab credit debit if pay_type2 == 1, cell
	svy: tab credit debit if pay_type2 == 2, cell
	svy: tab credit debit if pay_type2 == 3, cell
	svy: tab credit debit if pay_type2 == 4, cell
	svy: tab credit debit                  , cell	

* Finally, creating some variables for estimation  		
	generate small_dum1 = 0
	generate small_dum2 = 0
	generate credit_own = 0
	generate debit_own  = 0
	generate credit_one = 0
	generate gender_small = gender*small_dum2
	generate m_income = abs(gender-1)*log(income)
	generate urb_dummy  = 0
		
	replace small_dum1 = 1 if tv < 5
	replace small_dum2 = 1 if tv < 10
	replace credit_own = 1 if num_cc > 0
	replace debit_own  = 1 if num_dc > 0
	replace credit_one = 1 if num_cc == 1
	replace urb_dummy  = 1 if q49u == 1
		
	replace  d_fee     = 0 if d_fee  != 3
	replace  d_fee     = 1 if d_fee  == 3
	generate d_nolimit = 1 if free_n == 5
	replace  d_nolimit = 0 if d_nolimit != 1
		
	generate weekdaydum = 0
	replace  weekdaydum = 1 if ((t1a==1)|(t1a==7)|(t1a==8)|(t1a==14)| ///
								(t1a==15)|(t1a==21)|(t1a==22)|(t1a==28)| ///
							    (t1a==29))&(t1b==2)
	replace  weekdaydum = 1 if ((t1a==3)|(t1a==4)|(t1a==10)|(t1a==11)| ///
	                            (t1a==17)|(t1a==18)|(t1a==24)|(t1a==25)| ///
								(t1a==31))&(t1b==1)
	replace  weekdaydum = 1 if ((t1a==5)|(t1a==6)|(t1a==12)|(t1a==13)| ///
	                           (t1a==19)|(t1a==20)|(t1a==26)|(t1a==27))&(t1b==3)
		
	tab region, gen(region_)
    rename region_1 West
	rename region_2 Ontario
	rename region_3 Quebec 
	rename region_4 East
		 
	sort idnumber transnum2
		

* Table 10 is based on the following tabulation
	tab t10a pay_type2 if  (d_cash==1)&(debit==1)&(credit==1), mi
		
* Table 1 is based obtained by the following tabulations 
	svy: mean age income West Ontario Quebec East urb_dummy if transnum2 == 1
	svy: mean ease_cr keep_cr num_cc rewards c_limit OwingLastMonth ///
				if transnum2 == 1
	svy: mean ease_de keep_de num_dc d_nolimit d_fee LowBalance ///
				if transnum2 == 1
	svy: mean tv small_dum1 small_dum2 groc_dum gas_dum weekdaydum
	
			
			

/////////////////////////////////////////////////////////////////////////////
// PART IV. Exporting the data to csv files to run .m files in MatlabCodes //
/////////////////////////////////////////////////////////////////////////////

* Outsheeting several csv files for each model 					
	sort idnumber transnum2	
	
	cd ../MatlabCodes/EstimableData/
	
	* Basic version *
	outsheet idnumber transnum2 transnum3 wdsicap ///
		d_cash d_credit d_debit cash credit debit /// 1-10
		pay_type2 credit_own debit_own cas_never cre_never deb_never /// 11-16
		West Ontario Quebec /// 17 - 19
		using data_v44ind.csv, replace comma nonames nolabel
		
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_cr keep_cr num_cc rewards c_limit OwingLastMonth /// 12-17
		West Ontario Quebec /// 18 -20
		using data_CreMean.csv, replace comma nonames nolabel
				 
	outsheet tv ease_cr keep_cr num_cc rewards c_limit ///
		using data_CreRand.csv, replace comma nonames nolabel
				 
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_de keep_de num_dc LowBalance d_nolimit d_fee  /// 12-17
		West Ontario Quebec /// 18 - 20
		using data_DebMean.csv, replace comma nonames nolabel				 
				 
	outsheet tv  ease_de keep_de num_dc   /// 
		using data_DebRand.csv, replace comma nonames nolabel	
				 

	* Version 45e * 
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_cr keep_cr num_cc rewards c_limit OwingLastMonth /// 12-17
		West Ontario Quebec /// 18 -20
		cas_never cre_never deb_never /// 21- 23
		using data_CreMean45e.csv, replace comma nonames nolabel
				 
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_de keep_de num_dc LowBalance d_nolimit d_fee  /// 12-17
		West Ontario Quebec /// 18 - 20
		cas_never cre_never deb_never ///21-23
		using data_DebMean45e.csv, replace comma nonames nolabel				 
				 

	* Version 46 * 
	/*
	/* This data is for rubstness check and we do drop same samples. 
	   So, if you want to obtain Figure 1, please comment out this part */ 
		* Dropping some observations which does not have number of 
		* cash register information
		drop if register ==. & t6a ==2
		tab register t6a,  mi
		drop if register ==1 & t6a ==2
		* drop if channel is unknown
		drop if t6a ==.
		*dummy variable for no store
		gen d_no_store = t6a!=2
		* recode cash registers
		recode register(1= 0) (2 = 1) (3 = 3) (4  = 6) (. = 0)	
	
	outsheet idnumber transnum2 transnum3 wdsicap ///
		d_cash d_credit d_debit cash credit debit /// 1-10
		pay_type2 credit_own debit_own cas_never cre_never deb_never /// 11-16
		West Ontario Quebec /// 17 - 19
		d_no_store register aver_acc_cc aver_acc_dc /// 20 - 23
		using data_v46ind.csv, replace comma nonames nolabel
		
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_cr keep_cr num_cc rewards c_limit OwingLastMonth /// 12-17
		West Ontario Quebec /// 18 -20
		using data_v46CreMean.csv, replace comma nonames nolabel
				 
	outsheet tv ease_cr keep_cr num_cc rewards c_limit ///
		using data_v46CreRand.csv, replace comma nonames nolabel
				 
	outsheet tv tv_sq small_dum1 small_dum2 groc_dum ente_dum ///
		gas_dum weekdaydum age income urb_dummy /// 1-11
		ease_de keep_de num_dc LowBalance d_nolimit d_fee  /// 12-17
		West Ontario Quebec /// 18 - 20
		using data_v46DebMean.csv, replace comma nonames nolabel				 
				 
	outsheet tv ease_de keep_de num_dc   /// 
		using data_v46DebRand.csv, replace comma nonames nolabel		
	*/
	
//////////////////////////////// 
// PART V. Obtaining Figure 1 // 
//////////////////////////////// 
* Here we generate 8 graphs first and combine them at the end 
* We use smoothing technique here to draw Figure 1 
gen    tv_int = ceil(tv) 		
bysort tv_int:  gen eachnum = _n


* The following part correcponds to Figure 1(a)
local i=1
while `i'<11 { 
gen tv_int`i' = ceil( (tv+`i')/10 )
bysort tv_int`i': egen totalnum`i' = count(tv_int`i')
bysort tv_int`i': egen  totalca`i' = sum(  d_cash)
bysort tv_int`i': egen  totalcc`i' = sum(d_credit)
bysort tv_int`i': egen  totaldc`i' = sum( d_debit)
gen ca_ratio`i' = totalca`i'/totalnum`i'
gen cc_ratio`i' = totalcc`i'/totalnum`i'
gen dc_ratio`i' = totaldc`i'/totalnum`i'
local i = `i'+ 1 
}

gen ca_ratio = ( ca_ratio1 + ca_ratio2 + ca_ratio3 + ca_ratio4 + ///
                 ca_ratio5 + ca_ratio6 + ca_ratio7 + ca_ratio8 + ///
				 ca_ratio9 + ca_ratio10 )/10
gen cc_ratio = ( cc_ratio1 + cc_ratio2 + cc_ratio3 + cc_ratio4 + ///
                 cc_ratio5 + cc_ratio6 + cc_ratio7 + cc_ratio8 + ///
				 cc_ratio9 + cc_ratio10 )/10
gen dc_ratio = ( dc_ratio1 + dc_ratio2 + dc_ratio3 + dc_ratio4 + ///
                 dc_ratio5 + dc_ratio6 + dc_ratio7 + dc_ratio8 + ///
				 dc_ratio9 + dc_ratio10 )/10
twoway (line ca_ratio tv_int, lcolor(black) lwidth(0.5) lpattern(solid)) ///
    (line cc_ratio tv_int, lcolor(blue) lwidth(0.5) lpattern(dash) ) ///
	(line dc_ratio tv_int, lcolor(red) lwidth(0.5) lpattern(tight_dot) ) ///
	if eachnum==1 & tv < 100, ///
	title((a) All Transactions, justification(left)) ///
	xtitle(Transaction Value)  ylabel(0(0.25)1) xlabel(0(25)100) ///
	legend(label(1 "Cash") label(2 "Credit") label(3 "Debit"))
graph save Figure1a, replace


* The following part correcponds to Figure 1 (c) 
gen    tv_intB = ceil(tv) if (credit==1)&(debit==1)		
bysort tv_intB:  gen eachnumB = _n if (credit==1)&(debit==1)
	
local i=1
while `i'<11 { 
gen tv_intB`i' = ceil( (tv+`i')/10 ) if (credit==1)&(debit==1)
bysort tv_intB`i': egen totalnumB`i' = count(tv_intB`i') ///
                                                  if (credit==1)&(debit==1)
bysort tv_intB`i': egen totalcaB`i' = sum(d_cash) if (credit==1)&(debit==1)
   bysort tv_intB`i': egen totalccB`i' = sum(d_credit) ///
                                                  if (credit==1)&(debit==1)
bysort tv_intB`i': egen totaldcB`i' = sum(d_debit) ///
                                                  if (credit==1)&(debit==1)
gen ca_ratioB`i' = totalcaB`i'/totalnumB`i' if (credit==1)&(debit==1)
gen cc_ratioB`i' = totalccB`i'/totalnumB`i' if (credit==1)&(debit==1)
gen dc_ratioB`i' = totaldcB`i'/totalnumB`i' if (credit==1)&(debit==1)
local i = `i'+ 1 
}

gen ca_ratioB = ( ca_ratioB1 + ca_ratioB2 + ca_ratioB3 + ca_ratioB4 + ///
				  ca_ratioB5 + ca_ratioB6 + ca_ratioB7 + ca_ratioB8 + ///
				  ca_ratioB9 + ca_ratioB10 )/10 if (credit==1)&(debit==1)
gen cc_ratioB = ( cc_ratioB1 + cc_ratioB2 + cc_ratioB3 + cc_ratioB4 + ///
				  cc_ratioB5 + cc_ratioB6 + cc_ratioB7 + cc_ratioB8 + ///
				  cc_ratioB9 + cc_ratioB10 )/10 if (credit==1)&(debit==1)
gen dc_ratioB = ( dc_ratioB1 + dc_ratioB2 + dc_ratioB3 + dc_ratioB4 + ///
				  dc_ratioB5 + dc_ratioB6 + dc_ratioB7 + dc_ratioB8 + ///
				  dc_ratioB9 + dc_ratioB10 )/10 if (credit==1)&(debit==1)

twoway (line ca_ratioB tv_intB, lcolor(black) lwidth(0.5) lpattern(solid)) ///
	  (line cc_ratioB tv_intB, lcolor(blue) lwidth(0.5) lpattern(dash) ) ///
	  (line dc_ratioB tv_intB, lcolor(red) lwidth(0.5) lpattern(tight_dot) ) ///
	  if eachnumB==1 &  tv < 100, title("(c) Transactions") ///
	  title("Accept All Methods", suffix) xtitle(Transaction Value) ///
	  ylabel(0(0.25)1) xlabel(0(25)100) /// 
	  legend(label(1 "Cash") label(2 "Credit") label(3 "Debit"))
graph save Figure1c, replace
drop tv_int* totalnum* totalca* totalcc* totaldc*			
drop ca_ratio* cc_ratio* dc_ratio* eachnum


* The following part correcponds to Figure 1 (b1) to (b3) 
gen tv_intTCA = ceil(tv) if (pay_type2==1)
gen tv_intTCC = ceil(tv) if (pay_type2==3)
gen tv_intTDC = ceil(tv) if (pay_type2==2)
gen tv_intTNC = round(tv) if (pay_type2==4)

bysort tv_intTCA:  gen eachnumTCA = _n if (pay_type2==1)
bysort tv_intTCC:  gen eachnumTCC = _n if (pay_type2==3)
bysort tv_intTDC:  gen eachnumTDC = _n if (pay_type2==2)
bysort tv_intTNC:  gen eachnumTNC = _n if (pay_type2==4)

local i=1
while `i'<11 { 
gen tv_intTCA`i' = ceil( (tv+`i')/10 ) if (pay_type2==1)
bysort tv_intTCA`i': egen totalnumTCA`i' = count(tv_intTCA`i') /// 
                                                           if (pay_type2==1)
bysort tv_intTCA`i': egen  totalcaTCA`i' = sum(  d_cash)   if (pay_type2==1)
bysort tv_intTCA`i': egen  totalccTCA`i' = sum(d_credit)   if (pay_type2==1)
bysort tv_intTCA`i': egen  totaldcTCA`i' = sum( d_debit)   if (pay_type2==1)
gen ca_ratioTCA`i' = totalcaTCA`i'/totalnumTCA`i'          if (pay_type2==1)
gen cc_ratioTCA`i' = totalccTCA`i'/totalnumTCA`i'          if (pay_type2==1)
gen dc_ratioTCA`i' = totaldcTCA`i'/totalnumTCA`i'          if (pay_type2==1)
local i = `i'+ 1 
}


local i=1
while `i'<11 { 
gen tv_intTCC`i' = ceil( (tv+ (`i'-5) )/10 ) if (pay_type2==3)
bysort tv_intTCC`i': egen totalnumTCC`i' = count(tv_intTCC`i') if (pay_type2==3)
bysort tv_intTCC`i': egen  totalcaTCC`i' = sum(  d_cash)       if (pay_type2==3)
bysort tv_intTCC`i': egen  totalccTCC`i' = sum(d_credit)       if (pay_type2==3)
bysort tv_intTCC`i': egen  totaldcTCC`i' = sum( d_debit)       if (pay_type2==3)
gen ca_ratioTCC`i' = totalcaTCC`i'/totalnumTCC`i'              if (pay_type2==3)
gen cc_ratioTCC`i' = totalccTCC`i'/totalnumTCC`i'              if (pay_type2==3)
gen dc_ratioTCC`i' = totaldcTCC`i'/totalnumTCC`i'              if (pay_type2==3)
local i = `i'+ 1 
}

local i=1
while `i'<11 { 
gen tv_intTDC`i' = ceil( (tv+`i')/10 ) if (pay_type2==2)
bysort tv_intTDC`i': egen totalnumTDC`i' = count(tv_intTDC`i') if (pay_type2==2)
bysort tv_intTDC`i': egen  totalcaTDC`i' = sum(  d_cash)       if (pay_type2==2)
bysort tv_intTDC`i': egen  totalccTDC`i' = sum(d_credit)       if (pay_type2==2)
bysort tv_intTDC`i': egen  totaldcTDC`i' = sum( d_debit)       if (pay_type2==2)
gen ca_ratioTDC`i' = totalcaTDC`i'/totalnumTDC`i'              if (pay_type2==2)
gen cc_ratioTDC`i' = totalccTDC`i'/totalnumTDC`i'              if (pay_type2==2)
gen dc_ratioTDC`i' = totaldcTDC`i'/totalnumTDC`i'              if (pay_type2==2)
local i = `i'+ 1 
}

local i=1
while `i'<11 { 
gen tv_intTNC`i' = ceil( (tv+`i')/10 ) if (pay_type2==4)
bysort tv_intTNC`i': egen totalnumTNC`i' = count(tv_intTNC`i') if (pay_type2==4)
bysort tv_intTNC`i': egen  totalcaTNC`i' = sum(  d_cash)       if (pay_type2==4)
bysort tv_intTNC`i': egen  totalccTNC`i' = sum(d_credit)       if (pay_type2==4)
bysort tv_intTNC`i': egen  totaldcTNC`i' = sum( d_debit)       if (pay_type2==4)
gen ca_ratioTNC`i' = totalcaTNC`i'/totalnumTNC`i'              if (pay_type2==4)
gen cc_ratioTNC`i' = totalccTNC`i'/totalnumTNC`i'              if (pay_type2==4)
gen dc_ratioTNC`i' = totaldcTNC`i'/totalnumTNC`i'              if (pay_type2==4)
local i = `i'+ 1 
}

gen Gca_ratioTCA = ( ca_ratioTCA1 + ca_ratioTCA2 + ca_ratioTCA3 + ///
					 ca_ratioTCA4 + ca_ratioTCA5 + ca_ratioTCA6 + ///
					 ca_ratioTCA7 + ca_ratioTCA8 + ca_ratioTCA9 + ///
					 ca_ratioTCA10 )/10 if (pay_type2==1)
gen Gcc_ratioTCA = ( cc_ratioTCA1 + cc_ratioTCA2 + cc_ratioTCA3 + ///
					 cc_ratioTCA4 + cc_ratioTCA5 + cc_ratioTCA6 + ///
					 cc_ratioTCA7 + cc_ratioTCA8 + cc_ratioTCA9 + ///
					 cc_ratioTCA10 )/10 if (pay_type2==1)
gen Gdc_ratioTCA = ( dc_ratioTCA1 + dc_ratioTCA2 + dc_ratioTCA3 + ///
					 dc_ratioTCA4 + dc_ratioTCA5 + dc_ratioTCA6 + ///
					 dc_ratioTCA7 + dc_ratioTCA8 + dc_ratioTCA9 + ///
					 dc_ratioTCA10 )/10 if (pay_type2==1)
gen Gca_ratioTCC = ( ca_ratioTCC1 + ca_ratioTCC2 + ca_ratioTCC3 + ///
					 ca_ratioTCC4 + ca_ratioTCC5 + ca_ratioTCC6 + ///
					 ca_ratioTCC7 + ca_ratioTCC8 + ca_ratioTCC9 + ///
					 ca_ratioTCC10 )/10 if (pay_type2==3)
gen Gcc_ratioTCC = ( cc_ratioTCC1 + cc_ratioTCC2 + cc_ratioTCC3 + ///
					 cc_ratioTCC4 + cc_ratioTCC5 + cc_ratioTCC6 + ///
					 cc_ratioTCC7 + cc_ratioTCC8 + cc_ratioTCC9 + ///
					 cc_ratioTCC10 )/10 if (pay_type2==3)
gen Gdc_ratioTCC = ( dc_ratioTCC1 + dc_ratioTCC2 + dc_ratioTCC3 + ///
					 dc_ratioTCC4 + dc_ratioTCC5 + dc_ratioTCC6 + ///
					 dc_ratioTCC7 + dc_ratioTCC8 + dc_ratioTCC9 + ///
					 dc_ratioTCC10 )/10 if (pay_type2==3)
gen Gca_ratioTDC = ( ca_ratioTDC1 + ca_ratioTDC2 + ca_ratioTDC3 + ///
					 ca_ratioTDC4 + ca_ratioTDC5 + ca_ratioTDC6 + ///
					 ca_ratioTDC7 + ca_ratioTDC8 + ca_ratioTDC9 + ///
					 ca_ratioTDC10 )/10 if (pay_type2==2)
gen Gcc_ratioTDC = ( cc_ratioTDC1 + cc_ratioTDC2 + cc_ratioTDC3 + ///
					 cc_ratioTDC4 + cc_ratioTDC5 + cc_ratioTDC6 + ///
					 cc_ratioTDC7 + cc_ratioTDC8 + cc_ratioTDC9 + ///
					 cc_ratioTDC10 )/10 if (pay_type2==2)
gen Gdc_ratioTDC = ( dc_ratioTDC1 + dc_ratioTDC2 + dc_ratioTDC3 + ///
					 dc_ratioTDC4 + dc_ratioTDC5 + dc_ratioTDC6 + ///
					 dc_ratioTDC7 + dc_ratioTDC8 + dc_ratioTDC9 + ///
					 dc_ratioTDC10 )/10 if (pay_type2==2)
gen Gca_ratioTNC = ( ca_ratioTNC1 + ca_ratioTNC2 + ca_ratioTNC3 + ///
					 ca_ratioTNC4 + ca_ratioTNC5 + ca_ratioTNC6 + ///
					 ca_ratioTNC7 + ca_ratioTNC8 + ca_ratioTNC9 + ///
					 ca_ratioTNC10 )/10 if (pay_type2==4)
gen Gcc_ratioTNC = ( cc_ratioTNC1 + cc_ratioTNC2 + cc_ratioTNC3 + ///
					 cc_ratioTNC4 + cc_ratioTNC5 + cc_ratioTNC6 + ///
					 cc_ratioTNC7 + cc_ratioTNC8 + cc_ratioTNC9 + ///
					 cc_ratioTNC10 )/10 if (pay_type2==4)
gen Gdc_ratioTNC = ( dc_ratioTNC1 + dc_ratioTNC2 + dc_ratioTNC3 + ///
					 dc_ratioTNC4 + dc_ratioTNC5 + dc_ratioTNC6 + ///
					 dc_ratioTNC7 + dc_ratioTNC8 + dc_ratioTNC9 + ///
					 dc_ratioTNC10 )/10 if (pay_type2==4)
drop ca_ratioTCA* ca_ratioTCC* ca_ratioTDC* ca_ratioTNC*
drop cc_ratioTCA* cc_ratioTCC* cc_ratioTDC* cc_ratioTNC*
drop dc_ratioTCA* dc_ratioTCC* dc_ratioTDC* dc_ratioTNC*


sort tv_intTCC
twoway ///
  (line Gca_ratioTCC tv_intTCC, lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTCC tv_intTCC, lcolor(blue) lwidth(0.5) lpattern(dash)) /// 
  (line Gdc_ratioTCC tv_intTCC, lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTCC==1 & tv < 100, title((b1) Credit Users, justification(left)) ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1b1, replace

sort tv_intTDC
twoway ///
  (line Gca_ratioTDC tv_intTDC, lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTDC tv_intTDC, lcolor(blue) lwidth(0.5) lpattern(dash)) ///
  (line Gdc_ratioTDC tv_intTDC, lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTDC==1 & tv < 100, title((b2) Debit Users)  ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1b2, replace
	
sort tv_intTNC
twoway ///
  (line Gca_ratioTNC tv_intTNC, lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTNC tv_intTNC, lcolor(blue) lwidth(0.5) lpattern(dash)) ///
  (line Gdc_ratioTNC tv_intTNC, lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTNC==1 & tv < 100, title((b3) Mixed Users) ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1b3, replace


* The following part correcponds to Figure 1 (d1) to (d3) 
gen    tv_intTCCall = ceil(tv) if (pay_type2==3)&(credit==1)&(debit==1)
gen    tv_intTDCall = ceil(tv) if (pay_type2==2)&(credit==1)&(debit==1)
gen    tv_intTNCall = round(tv) if (pay_type2==4)&(credit==1)&(debit==1)
bysort tv_intTCCall:  gen eachnumTCCall = _n ///
                                       if (pay_type2==3)&(credit==1)&(debit==1)
bysort tv_intTDCall:  gen eachnumTDCall = _n ///
                                       if (pay_type2==2)&(credit==1)&(debit==1)
bysort tv_intTNCall:  gen eachnumTNCall = _n ///
                                       if (pay_type2==4)&(credit==1)&(debit==1)

local i=1
while `i'<11 { 
gen tv_intTCCall`i' = ceil( (tv+ (`i'-5) )/10 ) ///
                                       if (pay_type2==3)&(credit==1)&(debit==1)
bysort tv_intTCCall`i': egen totalnumTCCall`i' = count(tv_intTCCall`i') ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
bysort tv_intTCCall`i': egen  totalcaTCCall`i' = sum(  d_cash) ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
bysort tv_intTCCall`i': egen  totalccTCCall`i' = sum(d_credit) ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
bysort tv_intTCCall`i': egen  totaldcTCCall`i' = sum( d_debit) ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
gen ca_ratioTCCall`i' = totalcaTCCall`i'/totalnumTCCall`i' ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
gen cc_ratioTCCall`i' = totalccTCCall`i'/totalnumTCCall`i' ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
gen dc_ratioTCCall`i' = totaldcTCCall`i'/totalnumTCCall`i' ///
									   if (pay_type2==3)&(credit==1)&(debit==1)
local i = `i'+ 1 
}


local i=1
while `i'<11 { 
gen tv_intTDCall`i' = ceil( (tv+`i')/10 ) ///
										if (pay_type2==2)&(credit==1)&(debit==1)
bysort tv_intTDCall`i': egen totalnumTDCall`i' = count(tv_intTDCall`i') ///
										if (pay_type2==2)&(credit==1)&(debit==1)
bysort tv_intTDCall`i': egen  totalcaTDCall`i' = sum(  d_cash) ///
										if (pay_type2==2)&(credit==1)&(debit==1)
bysort tv_intTDCall`i': egen  totalccTDCall`i' = sum(d_credit) ///
										if (pay_type2==2)&(credit==1)&(debit==1)
bysort tv_intTDCall`i': egen  totaldcTDCall`i' = sum( d_debit) ///
										if (pay_type2==2)&(credit==1)&(debit==1)
gen ca_ratioTDCall`i' = totalcaTDCall`i'/totalnumTDCall`i' ///
										if (pay_type2==2)&(credit==1)&(debit==1)
gen cc_ratioTDCall`i' = totalccTDCall`i'/totalnumTDCall`i' ///
										if (pay_type2==2)&(credit==1)&(debit==1)
gen dc_ratioTDCall`i' = totaldcTDCall`i'/totalnumTDCall`i' ///
										if (pay_type2==2)&(credit==1)&(debit==1)
local i = `i'+ 1 
}

local i=1
while `i'<11 { 
gen tv_intTNCall`i' = ceil( (tv+`i')/10 ) ///
										if (pay_type2==4)&(credit==1)&(debit==1)
bysort tv_intTNCall`i': egen totalnumTNCall`i' = count(tv_intTNCall`i') ///
										if (pay_type2==4)&(credit==1)&(debit==1)
bysort tv_intTNCall`i': egen  totalcaTNCall`i' = sum(  d_cash) ///
										if (pay_type2==4)&(credit==1)&(debit==1)
bysort tv_intTNCall`i': egen  totalccTNCall`i' = sum(d_credit) ///
										if (pay_type2==4)&(credit==1)&(debit==1)
bysort tv_intTNCall`i': egen  totaldcTNCall`i' = sum( d_debit) ///
										if (pay_type2==4)&(credit==1)&(debit==1)
gen ca_ratioTNCall`i' = totalcaTNCall`i'/totalnumTNCall`i' /// 
										if (pay_type2==4)&(credit==1)&(debit==1)
gen cc_ratioTNCall`i' = totalccTNCall`i'/totalnumTNCall`i' ///
										if (pay_type2==4)&(credit==1)&(debit==1)
gen dc_ratioTNCall`i' = totaldcTNCall`i'/totalnumTNCall`i' /// 
										if (pay_type2==4)&(credit==1)&(debit==1)
local i = `i'+ 1 
}

gen Gca_ratioTCCall = ( ca_ratioTCCall1 + ca_ratioTCCall2 + ///
						ca_ratioTCCall3 + ca_ratioTCCall4 + ///
						ca_ratioTCCall5 + ca_ratioTCCall6 + ///
						ca_ratioTCCall7 + ca_ratioTCCall8 + ///
						ca_ratioTCCall9 + ca_ratioTCCall10 )/10 ///
						if (pay_type2==3)&(credit==1)&(debit==1)
gen Gcc_ratioTCCall = ( cc_ratioTCCall1 + cc_ratioTCCall2 + ///
						cc_ratioTCCall3 + cc_ratioTCCall4 + ///
						cc_ratioTCCall5 + cc_ratioTCCall6 + ///
						cc_ratioTCCall7 + cc_ratioTCCall8 + ///
						cc_ratioTCCall9 + cc_ratioTCCall10 )/10 ///
						if (pay_type2==3)&(credit==1)&(debit==1)
gen Gdc_ratioTCCall = ( dc_ratioTCCall1 + dc_ratioTCCall2 + ///
						dc_ratioTCCall3 + dc_ratioTCCall4 + ///
						dc_ratioTCCall5 + dc_ratioTCCall6 + ///
						dc_ratioTCCall7 + dc_ratioTCCall8 + ///
						dc_ratioTCCall9 + dc_ratioTCCall10 )/10 ///
						if (pay_type2==3)&(credit==1)&(debit==1)
gen Gca_ratioTDCall = ( ca_ratioTDCall1 + ca_ratioTDCall2 + ///
						ca_ratioTDCall3 + ca_ratioTDCall4 + ///
						ca_ratioTDCall5 + ca_ratioTDCall6 + ///
						ca_ratioTDCall7 + ca_ratioTDCall8 + ///
						ca_ratioTDCall9 + ca_ratioTDCall10 )/10 ///
						if (pay_type2==2)&(credit==1)&(debit==1)
gen Gcc_ratioTDCall = ( cc_ratioTDCall1 + cc_ratioTDCall2 + ///
						cc_ratioTDCall3 + cc_ratioTDCall4 + ///
						cc_ratioTDCall5 + cc_ratioTDCall6 + ///
						cc_ratioTDCall7 + cc_ratioTDCall8 + ///
						cc_ratioTDCall9 + cc_ratioTDCall10 )/10 ///
						if (pay_type2==2)&(credit==1)&(debit==1)
gen Gdc_ratioTDCall = ( dc_ratioTDCall1 + dc_ratioTDCall2 + ///
						dc_ratioTDCall3 + dc_ratioTDCall4 + ///
						dc_ratioTDCall5 + dc_ratioTDCall6 + ///
						dc_ratioTDCall7 + dc_ratioTDCall8 + ///
						dc_ratioTDCall9 + dc_ratioTDCall10 )/10 ///
						if (pay_type2==2)&(credit==1)&(debit==1)
gen Gca_ratioTNCall = ( ca_ratioTNCall1 + ca_ratioTNCall2 + ///
						ca_ratioTNCall3 + ca_ratioTNCall4 + ///
						ca_ratioTNCall5 + ca_ratioTNCall6 + ///
						ca_ratioTNCall7 + ca_ratioTNCall8 + ///
						ca_ratioTNCall9 + ca_ratioTNCall10 )/10 ///
						if (pay_type2==4)&(credit==1)&(debit==1)
gen Gcc_ratioTNCall = ( cc_ratioTNCall1 + cc_ratioTNCall2 + ///
						cc_ratioTNCall3 + cc_ratioTNCall4 + ///
						cc_ratioTNCall5 + cc_ratioTNCall6 + ///
						cc_ratioTNCall7 + cc_ratioTNCall8 + ///
						cc_ratioTNCall9 + cc_ratioTNCall10 )/10 ///
						if (pay_type2==4)&(credit==1)&(debit==1)
gen Gdc_ratioTNCall = ( dc_ratioTNCall1 + dc_ratioTNCall2 + ///
						dc_ratioTNCall3 + dc_ratioTNCall4 + ///
						dc_ratioTNCall5 + dc_ratioTNCall6 + ///
						dc_ratioTNCall7 + dc_ratioTNCall8 + ///
						dc_ratioTNCall9 + dc_ratioTNCall10 )/10 ///
						if (pay_type2==4)&(credit==1)&(debit==1)

sort tv_intTCCall
twoway ///
  (line Gca_ratioTCCall tv_intTCCall, ///
						lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTCCall tv_intTCCall, ///
						lcolor(blue) lwidth(0.5) lpattern(dash)) ///
  (line Gdc_ratioTCCall tv_intTCCall, ///
						lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTCCall==1 & tv < 100, title("(d1) Credit Users") ///
  title("Accept All Methods", suffix) ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1d1, replace

sort tv_intTDCall
twoway ////
  (line Gca_ratioTDCall tv_intTDCall, ////
						lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTDCall tv_intTDCall, ///
						lcolor(blue) lwidth(0.5) lpattern(dash)) ///
  (line Gdc_ratioTDCall tv_intTDCall, ///
						lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTDCall==1 & tv < 100, title("(d2) Debit Users") ///
  title("Accept All Methods", suffix) ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1d2, replace
	
sort tv_intTNCall
twoway ///
  (line Gca_ratioTNCall tv_intTNCall, ///
						lcolor(black) lwidth(0.5) lpattern(solid)) ///
  (line Gcc_ratioTNCall tv_intTNCall, ///
						lcolor(blue) lwidth(0.5) lpattern(dash)) ///
  (line Gdc_ratioTNCall tv_intTNCall, ///
						lcolor(red) lwidth(0.5) lpattern(tight_dot)) ///
  if eachnumTNCall==1 & tv < 100, title("(d3)  Mixed Users") ///
  title("Accept All Methods", suffix) ///
  xtitle(Transcation Value) ylabel(0(0.25)1) xlabel(0(25)100) legend(off)
graph save Figure1d3, replace


grc1leg  "Figure1a" "Figure1b1" "Figure1b2" "Figure1b3" ///
         "Figure1c" "Figure1d1" "Figure1d2" "Figure1d3" , ///
		 legendfrom("Figure1a") rows(2) 
graph export "Figure1.eps", as(eps) preview(off) replace	


erase Figure1a.gph 
erase Figure1b1.gph 
erase Figure1b2.gph 
erase Figure1b3.gph 
erase Figure1c.gph 
erase Figure1d1.gph 
erase Figure1d2.gph 
erase Figure1d3.gph 





